import React from "react";
import { TextInput, View, Text, StyleSheet } from "react-native";
import { connect } from "react-redux";

import tw from "tailwind-rn";
import Colors from "../constants/Colors";
import fontSize from "../constants/fontSize";

const FloatingLabelInput = ({
  label,
  textAlign,
  direction,
  labelBackgroundColor,
  onChange,
  name,
  value,
  textColor,
  placeholder,
  maxLength,
  autoFocus,
  regex,
  mobile,
  keyboardType,
  multiline,
  theme,
  editable = true,
  ...props
}) => {
  const [isFocused, setIsFocused] = React.useState(false);

  const styles = StyleSheet.create({
    labelStyle: {
      fontFamily: "regular",
      top: !isFocused ? "50%" : 1,
      fontSize: !isFocused
        ? Math.floor(fontSize.base)
        : Math.floor(fontSize.sm),
      transform: [
        {
          translateY: !isFocused
            ? -Math.floor(fontSize.base - 2)
            : -Math.floor(fontSize.sm),
        },
      ],
      backgroundColor : theme === 'light' ? Colors.theme1.white : Colors.theme1.dark,
      color: !isFocused ? theme === 'light' ? Colors.theme1.gray2077 : Colors.theme1.white + 'aa' : Colors.theme1.green79,
    },
    inputStyle: {
      fontSize: fontSize.lg,
      color: theme === 'light' ? Colors.theme1.black : Colors.theme1.white,
      borderWidth: 1,
      borderColor: isFocused
        ? Colors.theme1.greenC8
        : theme === "light" ? Colors.theme1.gray2077 + "66" : Colors.theme1.white + 'aa',
      textAlign: textAlign,
      fontFamily: "regular",
      direction: direction ? direction : "rtl",
    },
  });

  React.useEffect(() => {
    if (value) {
      setIsFocused(true);
    } else {
      setIsFocused(false);
    }
  }, [value]);

  return (
    <View style={tw("mt-4 pb-1")}>
      <Text
        style={[
          styles.labelStyle,
          tw("px-1 z-10 absolute right-3 text-center"),
        ]}
        onPress={() => setIsFocused(true)}
      >
        {label}
      </Text>
      <TextInput
        style={[
          styles.inputStyle,
          tw(`rounded-sm ${mobile ? "py-2" : "py-3"} px-4`),
        ]}
        onChangeText={(text) => onChange(name, (text = regex(text)))}
        placeholder={placeholder}
        onFocus={() => setIsFocused(true)}
        autoFocus={autoFocus}
        underlineColorAndroid={"transparent"}
        maxLength={maxLength}
        value={value}
        onBlur={() => (value ? {} : setIsFocused(() => false))}
        keyboardType={keyboardType}
        multiline={multiline}
        editable={editable}
        placeholderTextColor={theme === 'light' ? Colors.theme1.gray20 + 'aa' : Colors.theme1.white + '55'}
      />
    </View>
  );
};

const mapStateToProps = (state) => ({
  mobile: state.publicApi.mobile,
  theme: state.publicApi.theme,
});

export default connect(mapStateToProps)(FloatingLabelInput);
