import React, { useState, useEffect } from "react";
import {
  View,
  Platform,
  UIManager,
  Dimensions,
  Pressable,
  Text,
  TouchableOpacity,
  Image,
  LayoutAnimation,
  Animated,
} from "react-native";
import { useNavigation } from "@react-navigation/native";
import { asyncAwesomeAlert } from "../utils/AsyncWrappers";
import { connect } from "react-redux";
import { user, publicApi } from "../redux/actions";
import Svg, { Path, G } from "react-native-svg";
import { AntDesign } from "@expo/vector-icons";

//components
import Avatar from "../components/Avatar";

//style
import tw from "tailwind-rn";
import fontSize from "../constants/fontSize";
import Colors from "../constants/Colors";

//variables
const ios = Platform.OS === "ios";

if (
  Platform.OS === "android" &&
  UIManager.setLayoutAnimationEnabledExperimental
) {
  UIManager.setLayoutAnimationEnabledExperimental(true);
}

const Drawer = ({
  route,
  position,
  setBoxPosition,
  user,
  mobile,
  theme,
  setIsDark,
}) => {
  const [height, setHeight] = useState(Dimensions.get("window").height);
  const [width, setWidth] = useState(Dimensions.get("window").width);
  const fadeAnim = React.useRef(new Animated.Value(0)).current; // Initial value for opacity: 0
  const [dropdown, setDropdown] = useState(false);
  const [dropdownHeight, setDropdownHeight] = useState(0);
  const navigation = useNavigation();

  const routes = React.useMemo(() => {
    return [
      {
        name: "صفحه اصلی",
        route: "Home",
        icon: (
          <Svg
            data-name="vuesax/linear/home-2"
            xmlns="http://www.w3.org/2000/svg"
            width={24}
            height={24}
          >
            <G
              fill="none"
              stroke={
                theme === "light" ? Colors.theme1.gray20 : Colors.theme1.white
              }
              strokeLinecap="round"
              strokeLinejoin="round"
              strokeWidth={1.5}
            >
              <Path d="m9.02 2.84-5.39 4.2A4.759 4.759 0 0 0 2 10.36v7.41a4.225 4.225 0 0 0 4.21 4.22h11.58A4.223 4.223 0 0 0 22 17.78V10.5a4.723 4.723 0 0 0-1.8-3.45l-6.18-4.333a4.487 4.487 0 0 0-5 .123Z" />
              <Path data-name="Vector" d="M12 17.99v-3" />
            </G>
          </Svg>
        ),

        message: "",
      },
      {
        name: "فعال سازی",
        route: "Activation",
        icon: (
          <Svg
            xmlns="http://www.w3.org/2000/svg"
            width={21.431}
            height={21.431}
          >
            <G
              data-name="Group 1"
              fill="none"
              stroke={theme === "light" ? "#292d32" : Colors.theme1.white}
              strokeLinecap="round"
              strokeLinejoin="round"
              strokeWidth={1.5}
            >
              <Path d="M20.681 13.705V7.726c0-4.983-1.993-6.976-6.976-6.976H7.726C2.743.75.75 2.743.75 7.726v5.979c0 4.983 1.993 6.976 6.976 6.976h5.979c4.983 0 6.976-1.993 6.976-6.976Z" />
              <Path
                data-name="Vector"
                d="m6.558 10.716 2.776 2.776 5.538-5.552"
              />
            </G>
          </Svg>
        ),

        message: "",
      },
      {
        name: "واقعیت افزوده",
        route: "AR",
        icon: (
          <Svg
            data-name="vuesax/linear/3dcube"
            xmlns="http://www.w3.org/2000/svg"
            width={24}
            height={24}
          >
            <G
              data-name="3dcube"
              fill="none"
              stroke={theme === "light" ? "#292d32" : Colors.theme1.white}
              strokeLinecap="round"
              strokeLinejoin="round"
              strokeWidth={1.5}
            >
              <Path d="m12.92 2.26 6.51 3.51a1.153 1.153 0 0 1 0 1.99l-6.51 3.51a1.936 1.936 0 0 1-1.84 0L4.57 7.76a1.153 1.153 0 0 1 0-1.99l6.51-3.51a1.936 1.936 0 0 1 1.84 0Z" />
              <Path
                data-name="Vector"
                d="m3.61 10.13 6.05 3.03a2.238 2.238 0 0 1 1.23 1.99v5.72a1.109 1.109 0 0 1-1.61.99l-6.05-3.03A2.238 2.238 0 0 1 2 16.84v-5.72a1.109 1.109 0 0 1 1.61-.99ZM20.39 10.13l-6.05 3.03a2.238 2.238 0 0 0-1.23 1.99v5.72a1.109 1.109 0 0 0 1.61.99l6.05-3.03A2.238 2.238 0 0 0 22 16.84v-5.72a1.109 1.109 0 0 0-1.61-.99Z"
              />
            </G>
          </Svg>
        ),

        message: "",
      },
      {
        name: "وبلاگ",
        route: "Blogs",
        icon: (
          <Svg
            xmlns="http://www.w3.org/2000/svg"
            width={24.055}
            height={24.055}
          >
            <G
              fill="none"
              stroke={theme === "light" ? "#292d32" : Colors.theme1.white}
              strokeLinecap="round"
              strokeWidth={1.5}
              strokeLinejoin="round"
              data-name="vuesax/linear/note-2"
            >
              <Path d="m21.709 10.463-.982 4.19c-.842 3.618-2.506 5.081-5.633 4.781a10.538 10.538 0 0 1-1.624-.274l-1.684-.4c-4.178-.99-5.471-3.053-4.489-7.244l.982-4.2a10.5 10.5 0 0 1 .742-2.209c1.173-2.421 3.164-3.073 6.515-2.281l1.674.391c4.2.982 5.482 3.057 4.499 7.246Z" />
              <Path
                data-name="Vector"
                d="M15.091 19.435a9.394 9.394 0 0 1-2.352 1.083l-1.583.521c-3.979 1.283-6.074.21-7.367-3.767l-1.283-3.96c-1.283-3.98-.221-6.085 3.759-7.368l1.583-.521a10.247 10.247 0 0 1 1.173-.311 10.5 10.5 0 0 0-.742 2.205l-.982 4.195c-.982 4.19.31 6.255 4.487 7.247l1.684.4a10.538 10.538 0 0 0 1.626.271ZM12.669 8.549l4.862 1.233M13.641 12.428l2.906.742"
              />
            </G>
          </Svg>
        ),

        message: "",
      },
      {
        name: "سفارشات",
        route: "Orders",
        icon: (
          <Svg
            data-name="vuesax/linear/ranking"
            xmlns="http://www.w3.org/2000/svg"
            width={24}
            height={24}
          >
            <Path
              d="M8.67 14H4a2.006 2.006 0 0 0-2 2v6h6.67Z"
              fill="none"
              stroke={theme === "light" ? "#292d32" : Colors.theme1.white}
              strokeLinecap="round"
              strokeLinejoin="round"
              strokeWidth={1.5}
            />
            <Path
              data-name="Vector"
              d="M13.33 10h-2.67a2.006 2.006 0 0 0-2 2v10h6.67V12a2 2 0 0 0-2-2ZM20 17h-4.67v5H22v-3a2.006 2.006 0 0 0-2-2ZM12.52 2.07l.53 1.06a.6.6 0 0 0 .42.31l.96.16c.61.1.76.55.32.98l-.75.75a.639.639 0 0 0-.16.54l.21.92c.17.73-.22 1.01-.86.63l-.9-.53a.618.618 0 0 0-.59 0l-.9.53c-.64.38-1.03.1-.86-.63l.21-.92a.63.63 0 0 0-.156-.54l-.74-.74c-.44-.44-.3-.88.32-.98l.96-.16a.666.666 0 0 0 .42-.31l.53-1.06c.286-.58.746-.58 1.036-.01Z"
              fill="none"
              stroke={theme === "light" ? "#292d32" : Colors.theme1.white}
              strokeLinecap="round"
              strokeLinejoin="round"
              strokeWidth={1.5}
            />
          </Svg>
        ),

        message: "",
      },
      {
        name: "سوالات متداول",
        route: "Faq",
        icon: (
          <Svg
            data-name="vuesax/linear/lamp-on"
            xmlns="http://www.w3.org/2000/svg"
            width={24}
            height={24}
          >
            <G
              fill="none"
              stroke={theme === "light" ? "#292d32" : Colors.theme1.white}
              strokeLinecap="round"
              strokeLinejoin="round"
              strokeWidth={1.5}
            >
              <Path d="M8.3 18.04v-1.16a8.579 8.579 0 0 1-4.19-6.984A7.919 7.919 0 0 1 13.8 2.19a7.784 7.784 0 0 1 5.27 4.07c2.09 4.2-.11 8.66-3.34 10.61v1.16c0 .29.11.96-.96.96H9.26c-1.1.006-.96-.42-.96-.95Z" />
              <Path
                data-name="Vector"
                d="M8.5 21.999a12.808 12.808 0 0 1 7 0"
              />
            </G>
          </Svg>
        ),

        message: "",
      },
      {
        name: "تماس با ما",
        route: "Contact",
        icon: (
          <Svg
            data-name="vuesax/linear/call-calling"
            xmlns="http://www.w3.org/2000/svg"
            width={24}
            height={24}
          >
            <G
              data-name="call-calling"
              fill="none"
              stroke={theme === "light" ? "#292d32" : Colors.theme1.white}
              strokeWidth={1.5}
            >
              <Path d="M21.97 18.33a2.545 2.545 0 0 1-.25 1.09 4.126 4.126 0 0 1-.68 1.02 4.508 4.508 0 0 1-1.64 1.18 5.022 5.022 0 0 1-1.95.38 8.334 8.334 0 0 1-3.26-.73 17.564 17.564 0 0 1-3.44-1.98 28.75 28.75 0 0 1-3.28-2.8 28.414 28.414 0 0 1-2.79-3.27 17.828 17.828 0 0 1-1.96-3.41A8.423 8.423 0 0 1 2 6.54a5.173 5.173 0 0 1 .36-1.93 4.6 4.6 0 0 1 1.15-1.67A2.93 2.93 0 0 1 5.59 2a1.879 1.879 0 0 1 .81.18 1.63 1.63 0 0 1 .67.56l2.32 3.27a3.422 3.422 0 0 1 .4.7 1.581 1.581 0 0 1 .14.61 1.357 1.357 0 0 1-.21.71 3.4 3.4 0 0 1-.56.71l-.76.79a.535.535 0 0 0-.16.4.908.908 0 0 0 .03.23c.03.08.06.14.08.2a8.3 8.3 0 0 0 .93 1.28c.45.52.93 1.05 1.45 1.58.54.53 1.06 1.02 1.59 1.47a7.675 7.675 0 0 0 1.29.92c.05.02.11.05.18.08a.69.69 0 0 0 .25.04.55.55 0 0 0 .41-.17l.76-.75a3.068 3.068 0 0 1 .72-.56 1.332 1.332 0 0 1 .71-.21 1.6 1.6 0 0 1 .61.13 3.868 3.868 0 0 1 .7.39l3.31 2.35a1.517 1.517 0 0 1 .55.64 2.052 2.052 0 0 1 .16.78Z" />
              <Path
                data-name="Vector"
                d="M18.5 9a3.965 3.965 0 0 0-1.17-2.27A3.416 3.416 0 0 0 15 5.5M22 9a7 7 0 0 0-7-7"
                strokeLinecap="round"
                strokeLinejoin="round"
              />
            </G>
          </Svg>
        ),

        message: "",
      },
    ];
  }, [user, theme]);

  const Route = React.useCallback(
    ({ route }) => {
      return (
        <TouchableOpacity
          style={[
            tw(
              `w-full flex flex-row-reverse justify-start items-end ${
                mobile ? "mt-6" : "mt-10"
              }`
            ),
            {},
          ]}
          onPress={() => {
            setBoxPosition();
            setTimeout(() => {
              navigation.navigate(route.route);
            }, 300);
          }}
        >
          {route.icon}
          <Text
            style={[
              tw("mr-2"),
              {
                fontFamily: "regular",
                fontSize: mobile ? fontSize.base : fontSize.lg,
                color:
                  theme === "light"
                    ? Colors.theme1.gray20
                    : Colors.theme1.white,
              },
            ]}
          >
            {route.name}
          </Text>
        </TouchableOpacity>
      );
    },
    [mobile, position, theme]
  );

  React.useEffect(() => {
    if (position === "0%") {
      setTimeout(() => {
        Animated.timing(fadeAnim, {
          toValue: 0.7,
          duration: 300,
          useNativeDriver: true, // Add This line
        }).start();
      }, 300);
    }
    if (position === "100%") {
      Animated.timing(fadeAnim, {
        toValue: 0,
        duration: 10,
        useNativeDriver: true, // Add This line
      }).start();
    }
  }, [position]);

  const onLayout = React.useCallback(() => {
    setHeight(Dimensions.get("window").height);
    setWidth(Dimensions.get("window").width);
  }, [mobile]);

  const animateDropdown = React.useCallback(() => {
    LayoutAnimation.configureNext(LayoutAnimation.Presets.easeInEaseOut);
    setDropdown(() => !dropdown);
    setDropdownHeight(dropdownHeight === 0 ? fontSize.base + 30 : 0);
  }, [position]);

  return (
    <View
      style={[
        tw(`absolute top-0 flex flex-row justify-end`),
        {
          left: position,
          width: width,
          height: height,
          zIndex: 10000,
        },
      ]}
      onLayout={() => onLayout()}
    >
      <Animated.View
        style={[tw("w-1/5 h-full bg-black"), { opacity: fadeAnim }]}
      >
        <Pressable
          style={tw("flex-1 items-center pt-12")}
          onPress={() => setBoxPosition()}
        >
          <AntDesign
            name="close"
            size={mobile ? 25 : 30}
            color={Colors.theme1.white}
            onPress={() => setBoxPosition()}
          />
        </Pressable>
      </Animated.View>
      <View
        style={[
          tw("w-4/5 h-full flex"),
          {
            backgroundColor:
              theme === "light" ? Colors.theme1.white : Colors.theme1.dark,
          },
        ]}
      >
        <View
          style={[
            tw("flex items-end pt-12 px-4"),
            {
              backgroundColor:
                theme === "light"
                  ? Colors.theme1.greenCF
                  : Colors.theme1.blue90,
            },
          ]}
        >
          <View
            style={tw(
              "flex flex-row-reverse items-center w-full justify-between"
            )}
          >
            <Avatar souce={user?.picFileIds} size={width / 6} />
            {theme === "light" ? (
              <Svg
                xmlns="http://www.w3.org/2000/svg"
                onPress={() => setIsDark("dark")}
                width={24}
                height={24}
                style={{ padding: 10 }}
              >
                <Path
                  d="M2.03 12.42a10.506 10.506 0 0 0 18.93 5.3c.82-1.11.38-1.85-.99-1.6a9.494 9.494 0 0 1-2.08.14 9.324 9.324 0 0 1-8.91-9.12 8.9 8.9 0 0 1 .75-3.65c.54-1.24-.11-1.83-1.36-1.3a10.3 10.3 0 0 0-6.34 10.23Z"
                  fill="#fff"
                  data-name="vuesax/linear/moon"
                />
              </Svg>
            ) : (
              <Svg
                xmlns="http://www.w3.org/2000/svg"
                onPress={() => setIsDark("light")}
                width={24}
                height={24}
                style={{ padding: 10 }}
              >
                <G data-name="vuesax/linear/sun">
                  <Path
                    d="M18.5 12A6.5 6.5 0 1 1 12 5.5a6.5 6.5 0 0 1 6.5 6.5Z"
                    fill="#fff"
                  />
                  <Path
                    data-name="Vector"
                    d="m19.01 4.99.13-.13ZM4.86 19.14l.13-.13ZM12 2.08h0ZM12 22h0ZM2.08 12h0ZM22 12h0ZM4.99 4.99l-.13-.13Zm14.15 14.15-.13-.13"
                    fill="none"
                    stroke="#fff"
                    strokeLinecap="round"
                    strokeLinejoin="round"
                    strokeWidth={2}
                  />
                </G>
              </Svg>
            )}
          </View>

          <View
            style={tw(
              "flex flex-row-reverse w-full justify-between px-2 pb-1 mt-2"
            )}
          >
            <View style={tw("flex")}>
              <Text
                style={{
                  fontSize: mobile ? fontSize.lg : fontSize.xl,
                  color: "white",
                  fontFamily: "demi",
                  textAlign: ios ? "right" : "auto",
                }}
              >
                {user?.firstName + " " + user?.lastName}
              </Text>
              <Text
                style={{
                  fontSize: mobile ? fontSize.tiny : fontSize.lg,
                  color: "white",
                  fontFamily: "bold",
                  marginTop: 5,
                  textAlign: "right",
                }}
              >
                {user?.cellphone}
              </Text>
            </View>
            {/* <Svg
              data-name="vuesax/linear/arrow-left"
              xmlns="http://www.w3.org/2000/svg"
              width={24}
              height={24}
              style={{
                transform: [{ rotate: dropdown ? "90deg" : "-90deg" }],
                padding: 10,
              }}
              onPress={() => animateDropdown()}
            >
              <Path
                d="M15.002 19.92 8.479 13.4a1.986 1.986 0 0 1 0-2.8l6.523-6.52"
                fill="none"
                stroke="#fff"
                strokeLinecap="round"
                strokeLinejoin="round"
                strokeWidth={2}
              />
            </Svg> */}
          </View>
        </View>
        <View style={tw("flex-1 flex")}>
          {/* <Pressable
            style={[
              tw(
                `flex flex-row justify-between items-center w-full flex-row-reverse px-4 overflow-hidden`
              ),
              {
                borderBottomWidth: 1,
                borderColor: Colors.theme1.grayE3,
                height: dropdownHeight,
              },
            ]}
            onPress={() =>
              asyncAwesomeAlert("نتیجه", "این قابلیت در حال توسعه است.", {
                showCancelButton: false,
                confirmText: "باشه",
              })
            }
          >
            <Text
              style={{
                fontSize: mobile ? fontSize.base : fontSize.xl,
                fontFamily: "regular",
                color: Colors.theme1.gray20,
              }}
            >
              افزودن حساب کاربری جدید
            </Text>
            <Text
              style={{
                marginRight: 5,
                marginTop: 3,
                fontSize: fontSize.xl4,
                fontFamily: "bold",
                color: Colors.theme1.gray20 + "77",
              }}
            >
              +
            </Text>
          </Pressable> */}
          <View style={tw("flex w-full px-4")}>
            {routes.map((route, index) => (
              <Route route={route} key={index} />
            ))}
          </View>
        </View>
      </View>
    </View>
  );
};

const mapStateToProps = (state) => ({
  user: state.user.status,
  mobile: state.publicApi.mobile,
  theme: state.publicApi.theme,
});

const mapDispatchToProps = {
  logout: user.logout,
  setIsDark: publicApi.setIsDark,
};

export default connect(mapStateToProps, mapDispatchToProps)(Drawer);
