import React, { useCallback } from "react";
import {
  View,
  Pressable,
  Text,
  Appearance,
  TouchableOpacity,
  ActivityIndicator,
} from "react-native";

import Svg, {
  G,
  Defs,
  Pattern,
  Image as Imagee,
  Path,
  Text as Textt,
  TSpan,
  LinearGradient,
  Stop,
  ClipPath,
  Circle,
} from "react-native-svg";

import { useNavigation } from "@react-navigation/native";
import { Ionicons, Entypo } from "@expo/vector-icons";

import { connect } from "react-redux";
import { userFavorite } from "../redux/actions";

//style
import Colors from "../constants/Colors";
import tw from "tailwind-rn";
import fontSize from "../constants/fontSize";

const Navbar = ({
  notification,
  setBoxPosition,
  headerOptions,
  addToBookmark,
  deleteBookmark,
  userFavoriteList,
  theme,
  bookmarkLoading,
}) => {
  const navigation = useNavigation();

  const isActiveBookmark = React.useMemo(() => {
    return userFavoriteList.filter((object) =>
      headerOptions.bookmarkItem?.productId
        ? object.productId === headerOptions.bookmarkItem?.productId
        : object.contentId === headerOptions.bookmarkItem?.contentId
    ).length;
  }, [headerOptions, userFavoriteList]);

  const Button = useCallback(
    ({ icon, route, state }) => {
      return (
        <TouchableOpacity
          style={[
            tw("rounded-md p-1"),
            {
              backgrounds: Colors.theme1.greenCF + "05",
              borderColor:
                theme === "light" ? Colors.theme1.green79 : Colors.theme1.white,
              borderWidth: 1,
              marginLeft: route === "AR" ? 10 : 0,
            },
          ]}
          onPress={() => navigation.navigate(route, { page: state })}
        >
          {icon}
        </TouchableOpacity>
      );
    },
    [theme]
  );
  return (
    <View
      style={[
        tw("w-full flex flex-row-reverse justify-between items-center px-0"),
        {
          backgroundColor: headerOptions?.backgroundColor
            ? headerOptions?.backgroundColor
            : theme === "light"
            ? Colors.theme1.white
            : Colors.theme1.dark,
          height: 64,
        },
      ]}
    >
      {!headerOptions?.title ? (
        headerOptions?.back ? (
          <Ionicons
            name="arrow-forward"
            style={tw("mr-2")}
            size={24}
            color={
              theme === "light" ? Colors.theme1.green79 : Colors.theme1.white
            }
            onPress={() => navigation.goBack()}
          />
        ) : null
      ) : null}
      {headerOptions?.title ? (
        <Text
          style={{
            fontFamily: "demi",
            fontSize: fontSize.xl,
            color:
              theme === "light" ? Colors.theme1.green79 : Colors.theme1.white,
            paddingRight: 16,
          }}
        >
          {headerOptions?.title}
        </Text>
      ) : null}
      {headerOptions?.hamburgerMenu ? (
        <Pressable style={tw("relative mr-4")} onPress={() => setBoxPosition()}>
          <Svg
            xmlns="http://www.w3.org/2000/svg"
            width={31.567}
            height={29.996}
          >
            <G
              fill="none"
              stroke={
                theme === "light" ? Colors.theme1.green79 : Colors.theme1.white
              }
              strokeLinecap="round"
              strokeLinejoin="round"
              strokeWidth={2}
            >
              <Path d="M1 1h29.567" />
              <Path
                data-name="Vector"
                d="M1 9.999h29.567M1 18.998h29.567M1 27.996h29.567"
              />
            </G>
          </Svg>
          {notification ? (
            <View
              style={tw("h-2.5 w-2.5 absolute -left-1 -top-1 rounded-full")}
            ></View>
          ) : null}
        </Pressable>
      ) : null}

      {headerOptions?.logo ? (
        <Pressable
          onPress={() => navigation.navigate("Home")}
          style={tw("absolute right-1/2 top-1/2")}
        >
          <Svg
            xmlns="http://www.w3.org/2000/svg"
            xmlnsXlink="http://www.w3.org/1999/xlink"
            width={26.198}
            height={40.393}
            style={{ transform: [{ translateX: -13 }, { translateY: -21 }] }}
          >
            <Defs>
              <LinearGradient
                id="a"
                y1={0.5}
                x2={1}
                y2={0.5}
                gradientUnits="objectBoundingBox"
              >
                <Stop offset={0} stopColor="#5a595d" />
                <Stop offset={1} stopColor="#515254" />
              </LinearGradient>
              <LinearGradient
                id="c"
                x1={0.226}
                y1={0.051}
                x2={0.802}
                y2={0.929}
                gradientUnits="objectBoundingBox"
              >
                <Stop offset={0} stopColor="#fff" />
                <Stop offset={0.461} stopColor="#636466" />
                <Stop offset={1} stopColor="#4a4a4c" />
              </LinearGradient>
              <LinearGradient
                id="e"
                x1={0.118}
                y1={0.331}
                x2={1.017}
                y2={0.638}
                gradientUnits="objectBoundingBox"
              >
                <Stop offset={0} stopColor="#c3e14b" />
                <Stop offset={0.528} stopColor="#4cdb60" />
                <Stop offset={1} stopColor="#4fb84a" />
              </LinearGradient>
              <LinearGradient
                id="f"
                y1={0.5}
                x2={1}
                y2={0.5}
                gradientUnits="objectBoundingBox"
              >
                <Stop offset={0} stopColor="#8bc540" />
                <Stop offset={1} stopColor="#4fb84a" />
              </LinearGradient>
              <LinearGradient
                id="b"
                x1={0.177}
                y1={0.211}
                x2={0.923}
                y2={0.878}
                gradientUnits="objectBoundingBox"
              >
                <Stop offset={0.156} stopColor="#c3e14b" />
                <Stop offset={0.628} stopColor="#4cdb60" />
                <Stop offset={1} stopColor="#4fb84a" />
              </LinearGradient>
              <LinearGradient
                id="g"
                x1={0}
                y1={0.5}
                x2={1}
                y2={0.5}
                xlinkHref="#b"
              />
              <ClipPath id="d">
                <Path
                  data-name="Path 11452"
                  d="M752.773 683.017c0-1.668.08-8.506-.023-8.462-.33 3.666-3.285 6.412-8.535 6.412a6.347 6.347 0 0 1-5.966-3.826c-3.262-2.317-3.731-4.787-3.731-4.787l.058 13.66v.011h15.133a2.759 2.759 0 0 0 3.064-3.008Z"
                  transform="translate(-734.518 -672.354)"
                  fill="url(#a)"
                />
              </ClipPath>
            </Defs>
            <G data-name="Group 2024">
              <G data-name="Layer 10">
                <G data-name="Group 2013">
                  <G data-name="Group 2009">
                    <Path
                      data-name="Path 11446"
                      d="M2.534 4.411H.053s-.255 1.422.328 2.005 2.151.534 2.151.862Z"
                      fill="#7f8083"
                    />
                  </G>
                  <Path
                    data-name="Path 11447"
                    d="M758.141 245.564h-1.422a3.668 3.668 0 0 0-3.937 3.718l-.009 26.913a2.759 2.759 0 0 1-3.062 3.008h-11.462v-8.884a10.446 10.446 0 0 1-1.033-4.34v-16.915c0-2.552-2.7-3.172-2.7-3.172v19.64l.108 13.671h-.049c.014.113.032.221.052.325v.006c.4 2.152 1.868 2.339 3.57 2.339h14.509c2.953 0 2.771-2.552 2.771-4.229V250.23c0-2.078.984-1.677 1.969-2.005s.695-2.661.695-2.661Z"
                    transform="translate(-731.983 -241.481)"
                    fill="url(#c)"
                  />
                  <G data-name="Group 2010">
                    <Path
                      data-name="Path 11448"
                      d="M2.593 37.722Z"
                      fill="#4b4b4d"
                    />
                  </G>
                  <G data-name="Group 2012">
                    <Path
                      data-name="Path 11449"
                      d="M752.773 683.017c0-1.668.08-8.506-.023-8.462-.33 3.666-3.285 6.412-8.535 6.412a6.347 6.347 0 0 1-5.966-3.826c-3.262-2.317-3.731-4.787-3.731-4.787l.058 13.66v.011h15.133a2.759 2.759 0 0 0 3.064-3.008Z"
                      transform="translate(-731.983 -648.303)"
                      fill="url(#a)"
                    />
                    <G
                      data-name="Group 2011"
                      clipPath="url(#d)"
                      fill="#fff"
                      transform="translate(2.535 24.051)"
                    >
                      <Path data-name="Path 11450" d="M0 0Z" />
                      <Path data-name="Path 11451" d="M18.392 13.671Z" />
                    </G>
                  </G>
                </G>
              </G>
              <G data-name="Layer 7">
                <Path
                  data-name="Path 11453"
                  d="M802.306 400.555v12.358c0 1.6 1.9 6.854 7.036 6.854a7.19 7.19 0 0 0 7.437-6.562v-12.65a4.138 4.138 0 0 0-3.1-1.495c-1.969 0-4.393 1.566-6.289 2.149a5.78 5.78 0 0 1-4.024.094 3.059 3.059 0 0 1-1.06-.748Z"
                  transform="translate(-796.6 -387.795)"
                  fill="url(#e)"
                />
              </G>
              <G data-name="Layer 8">
                <Path
                  data-name="Path 11454"
                  d="M816.779 400.576a5.934 5.934 0 0 0-4.63.115c-3.017 1.611-6.088 5.171-7.546 7.376s-2.3 3.664-2.3 3.664v-11.155a3.594 3.594 0 0 0 2.012 1 8.558 8.558 0 0 0 4.794-1.044 11.537 11.537 0 0 1 4.476-1.449 3.977 3.977 0 0 1 2.433.784c.67.417.761.709.761.709Z"
                  transform="translate(-796.6 -387.816)"
                  fill="url(#f)"
                />
              </G>
              <G data-name="Layer 9">
                <G data-name="Group 2014">
                  <Path
                    data-name="Path 11455"
                    d="M12.751 12.6a6.145 6.145 0 0 0-3.727-1.335 4.267 4.267 0 0 0-3.317 1.495 3.672 3.672 0 0 0 2.232 1.029 8.888 8.888 0 0 0 4.812-1.189Z"
                    fill="#09793e"
                  />
                </G>
              </G>
              <G data-name="Layer 5" transform="translate(12.159 5.432)">
                <Circle
                  data-name="Ellipse 177"
                  cx={2.06}
                  cy={2.06}
                  r={2.06}
                  fill="url(#b)"
                />
                <G data-name="Group 2018">
                  <G data-name="Group 2015" transform="translate(2.394 1.041)">
                    <Circle
                      data-name="Ellipse 178"
                      cx={0.361}
                      cy={0.361}
                      r={0.361}
                      fill="#6c3b41"
                    />
                  </G>
                  <G data-name="Group 2016" transform="translate(.973 1.041)">
                    <Circle
                      data-name="Ellipse 179"
                      cx={0.361}
                      cy={0.361}
                      r={0.361}
                      fill="#6c3b41"
                    />
                  </G>
                  <G data-name="Group 2017">
                    <Path
                      data-name="Path 11456"
                      d="M2.068 3.185a1.594 1.594 0 0 1-1.286-.923l.194-.091c0 .008.386.8 1.092.8.706 0 1.073-.791 1.077-.8l.195.088a1.562 1.562 0 0 1-1.272.926Z"
                      fill="#6c3b41"
                    />
                  </G>
                </G>
              </G>
              <G data-name="Layer 3" transform="translate(8.294 3.336)">
                <Circle
                  data-name="Ellipse 180"
                  cx={1.075}
                  cy={1.075}
                  r={1.075}
                  fill="url(#g)"
                />
              </G>
              <G data-name="Layer 4">
                <G data-name="Group 2019" transform="translate(12.778)">
                  <Circle
                    data-name="Ellipse 181"
                    cx={0.547}
                    cy={0.547}
                    r={0.547}
                    fill="url(#g)"
                  />
                </G>
              </G>
              <G data-name="Layer 6">
                <G data-name="Group 2020" transform="translate(12.158 23.751)">
                  <Circle
                    data-name="Ellipse 182"
                    cx={2.06}
                    cy={2.06}
                    r={2.06}
                    fill="#fff"
                  />
                </G>
                <G data-name="Group 2021" transform="translate(9.743 21.162)">
                  <Circle
                    data-name="Ellipse 183"
                    cx={1.075}
                    cy={1.075}
                    r={1.075}
                    fill="#fff"
                  />
                </G>
                <G data-name="Group 2022" transform="translate(12.532 18.571)">
                  <Circle
                    data-name="Ellipse 184"
                    cx={0.547}
                    cy={0.547}
                    r={0.547}
                    fill="#fff"
                  />
                </G>
                <G data-name="Group 2023" transform="translate(11.247 34.222)">
                  <Circle
                    data-name="Ellipse 185"
                    cx={1.777}
                    cy={1.777}
                    r={1.777}
                    fill="#fff"
                  />
                </G>
              </G>
            </G>
          </Svg>
        </Pressable>
      ) : null}

      <View style={tw("flex flex-row items-center ml-4")}>
        {headerOptions?.back ? (
          headerOptions?.title ? (
            <Ionicons
              name="arrow-back"
              style={tw("mr-2")}
              size={24}
              color={
                theme === "light" ? Colors.theme1.green79 : Colors.theme1.white
              }
              onPress={() => navigation.goBack()}
            />
          ) : null
        ) : null}
        {headerOptions?.qr ? (
          <>
            <Button
              icon={
                <Svg xmlns="http://www.w3.org/2000/svg" width={30} height={30}>
                  <G
                    fill={
                      theme === "light"
                        ? Colors.theme1.green79
                        : Colors.theme1.white
                    }
                  >
                    <Path
                      data-name="Path 11446"
                      d="M2.131.275A3.177 3.177 0 0 0 .114 2.841 24.849 24.849 0 0 0 .045 5.98l.069 2.177h8.02V.137L5.499.091a18.649 18.649 0 0 0-3.368.184Zm4.973 3.873v2.979H1.146V4.973c0-2.452.229-3.277.962-3.575a13.17 13.17 0 0 1 2.773-.206l2.223-.023Z"
                    />
                    <Path
                      data-name="Path 11447"
                      d="M2.521 4.263v1.742l1.673-.069 1.65-.069.069-1.673.068-1.65h-3.46Z"
                    />
                    <Path
                      data-name="Path 11448"
                      d="M9.77.161a1.028 1.028 0 0 0-.16.6c0 .3.16.412.6.412.481 0 .573-.092.5-.5-.069-.535-.619-.81-.94-.512Z"
                    />
                    <Path
                      data-name="Path 11449"
                      d="M16.888.71c0 .573-.092.687-.573.687-.412 0-.573.115-.573.458s.16.458.573.458c.481 0 .573.115.573.687 0 .665-.023.687-1.146.687-.985 0-1.146.069-1.146.458s.16.458 1.146.458c1.123 0 1.146.023 1.146.687s.023.687 1.146.687h1.146v1.146c0 1.077.046 1.146.573 1.146.55 0 .573-.046.573-1.719s-.023-1.719-.573-1.719c-.458 0-.573-.115-.573-.573s-.115-.573-.573-.573c-.55 0-.573-.069-.573-1.26v-1.26h1.169c1.077 0 1.146-.046 1.077-.527-.069-.458-.206-.5-1.719-.573l-1.673-.069Z"
                    />
                    <Path
                      data-name="Path 11450"
                      d="M21.842.298a39.658 39.658 0 0 0-.069 4.079l.069 3.781h8.02V5.294c0-4.721-.367-5.087-4.973-5.225-2.36-.069-2.956-.023-3.047.229Zm6.325 1.306c.5.412.55.642.619 2.979l.092 2.544h-6V1.166h2.383c1.989 0 2.47.072 2.905.438Z"
                    />
                    <Path
                      data-name="Path 11451"
                      d="M24.248 4.263v1.719h3.208V2.544h-3.208Z"
                    />
                    <Path
                      data-name="Path 11452"
                      d="M11.966 1.856c0 .39.16.458 1.146.458s1.146-.069 1.146-.458-.16-.458-1.146-.458-1.146.069-1.146.458Z"
                    />
                    <Path
                      data-name="Path 11453"
                      d="M10.735 3.117c0 .458-.115.573-.573.573h-.573v5.729H8.444c-1.077 0-1.146.046-1.146.573 0 .458.115.573.573.573s.573.115.573.573.115.573.573.573.573-.115.573-.573c0-.527.069-.573 1.146-.573h1.146V9.419c0-1.077-.046-1.146-.573-1.146s-.573-.069-.573-1.146V5.981h2.292V4.835c0-1.077-.046-1.146-.573-1.146-.458 0-.573-.115-.573-.573s-.116-.572-.574-.572-.573.115-.573.573Z"
                    />
                    <Path
                      data-name="Path 11454"
                      d="M14.517 7.284c0 1.077-.046 1.146-.573 1.146-.55 0-.573.046-.573 1.719 0 1.558.046 1.719.458 1.719.344 0 .458-.16.458-.573 0-.458.115-.573.573-.573h.573V8.43c0-2.131-.023-2.292-.458-2.292-.389 0-.458.16-.458 1.146Z"
                    />
                    <Path
                      data-name="Path 11455"
                      d="M12.046 7.628c-.183.458.092.8.619.8.321 0 .435-.16.435-.573s-.114-.571-.463-.571a.674.674 0 0 0-.591.344Z"
                    />
                    <Path
                      data-name="Path 11456"
                      d="M16.876 7.884c0 .481.092.573.527.5a.638.638 0 0 0 .573-.6c.069-.412-.023-.5-.5-.5s-.6.115-.6.6Z"
                    />
                    <Path
                      data-name="Path 11457"
                      d="M.16 9.795A2.612 2.612 0 0 0 0 10.941v.985h1.146c1.077 0 1.146-.046 1.146-.573 0-.458-.115-.573-.573-.573s-.573-.115-.573-.573c0-.412-.115-.573-.412-.573a.9.9 0 0 0-.574.161Z"
                    />
                    <Path
                      data-name="Path 11458"
                      d="M4.812 10.198c0 .5.092.6.527.527a.512.512 0 0 0 .5-.527.512.512 0 0 0-.5-.527c-.435-.068-.527.023-.527.527Z"
                    />
                    <Path
                      data-name="Path 11459"
                      d="M17.145 11.164c0 1.1-.046 1.169-.573 1.169-.458 0-.573.115-.573.573v.573h4.583v-.573c0-.458.115-.573.573-.573s.573-.115.573-.573c0-.55.069-.573 1.26-.573s1.26.046 1.26.55c0 .435-.137.573-.619.642-.5.046-.665.206-.71.687-.069.5-.206.642-.642.642s-.55.115-.55.573-.115.573-.573.573-.573.115-.573.573-.115.573-.573.573-.573-.115-.573-.573-.115-.573-.573-.573-.573.115-.573.573-.115.573-.573.573c-.412 0-.573.115-.573.458s.16.458.573.458c.481 0 .573.115.573.687s-.092.687-.573.687c-.458 0-.573.115-.573.573 0 .527.069.573 1.146.573h1.146v5.729h1.146c1.123 0 1.146.023 1.146.687s-.023.687-1.146.687c-.985 0-1.146.069-1.146.458s.16.458 1.146.458c1.077 0 1.146.046 1.146.573v.573h4.812v1.4l1.673-.069c1.512-.069 1.65-.115 1.719-.6.069-.435-.023-.5-.619-.5-.71 0-.71 0-.71-1.26s0-1.26.687-1.26h.71l-.069-1.673-.069-1.65-2.336-.071-2.36-.069V20.58h1.146c1.077 0 1.146-.046 1.146-.573 0-.458.115-.573.573-.573s.573-.115.573-.573-.115-.573-.573-.573-.573-.115-.573-.573c0-.527-.069-.573-1.146-.573s-1.146-.046-1.146-.573c0-.412-.115-.573-.458-.573s-.458.16-.458.573c0 .481-.115.573-.687.573s-.687.092-.687.573c0 .458-.115.573-.573.573s-.573.115-.573.573-.115.573-.573.573-.573-.115-.573-.573-.115-.573-.573-.573c-.481 0-.573-.115-.573-.687 0-.665.023-.687 1.146-.687 1.077 0 1.146-.046 1.146-.573 0-.458.115-.573.573-.573s.573-.115.573-.573.115-.573.573-.573.573-.115.573-.573c0-.55.069-.573 1.26-.573 1.237 0 1.26 0 1.26.687 0 .573-.092.687-.573.687-.412 0-.573.115-.573.458 0 .39.16.458 1.146.458 1.077 0 1.146.046 1.146.573 0 .756.848.8.962.046.046-.367.252-.527.71-.573.435-.046.619-.206.619-.527s-.16-.435-.687-.435c-.573 0-.687-.092-.687-.573 0-.458-.115-.573-.573-.573-.481 0-.573-.115-.573-.687s-.092-.687-.573-.687c-.527 0-.573-.069-.573-1.146v-1.146h-5.73v.573a.6.6 0 0 1-1.192.046c-.069-.435-.229-.5-1.146-.573l-1.1-.069Zm9.4 7.7c0 .481-.115.573-.687.573s-.687-.092-.687-.573.115-.573.687-.573.682.091.682.572Zm-2.346 3.482-.069 1.787-1.764.069-1.787.069v-3.689h3.689Zm2.337 3.391c0 .458.115.573.573.573.481 0 .573.115.573.687 0 .619-.069.687-.687.687-.573 0-.687-.092-.687-.573 0-.412-.115-.573-.458-.573s-.458.16-.458.573c0 .55-.069.573-1.26.573-1.237 0-1.26 0-1.26-.687 0-.573.092-.687.573-.687.458 0 .573-.115.573-.573 0-.55.069-.573 1.26-.573s1.262.024 1.262.574Z"
                    />
                    <Path
                      data-name="Path 11460"
                      d="M21.725 21.73a.9.9 0 0 0-.16.573c0 .3.16.412.573.412.458 0 .573-.115.573-.573 0-.412-.115-.573-.412-.573a.9.9 0 0 0-.574.161Z"
                    />
                    <Path
                      data-name="Path 11461"
                      d="M28.831 10.176c0 .481.115.6.6.6s.573-.092.5-.527a.636.636 0 0 0-.573-.573c-.435-.073-.527.019-.527.5Z"
                    />
                    <Path
                      data-name="Path 11462"
                      d="M3.667 11.391c0 .458-.115.573-.573.573-.527 0-.573.069-.573 1.146 0 .985.069 1.146.458 1.146.344 0 .458-.16.458-.573v-.573h2.429c2.383 0 2.406 0 2.337-.527-.069-.458-.206-.5-1.833-.573-1.719-.069-1.787-.092-1.787-.619 0-.412-.115-.573-.458-.573s-.458.16-.458.573Z"
                    />
                    <Path
                      data-name="Path 11463"
                      d="M27.686 11.37c0 .412.115.573.458.573s.458-.16.458-.573-.116-.573-.458-.573-.458.16-.458.573Z"
                    />
                    <Path
                      data-name="Path 11464"
                      d="M9.77 12.106a1.027 1.027 0 0 0-.16.6c0 .3.16.412.6.412.481 0 .573-.092.5-.5-.069-.535-.619-.81-.94-.512Z"
                    />
                    <Path
                      data-name="Path 11465"
                      d="M0 14.996v1.6h1.719c1.558 0 1.719-.046 1.719-.458 0-.344-.16-.458-.573-.458-.458 0-.573-.115-.573-.573s-.115-.573-.573-.573-.573-.115-.573-.573-.115-.565-.573-.565c-.55 0-.573.046-.573 1.6Z"
                    />
                    <Path
                      data-name="Path 11466"
                      d="M8.438 13.829c0 .344.16.458.573.458s.573-.115.573-.458-.161-.458-.573-.458-.573.115-.573.458Z"
                    />
                    <Path
                      data-name="Path 11467"
                      d="M13.371 14.414c0 .871.069 1.031.458 1.031.344 0 .458-.16.458-.573 0-.458.115-.573.573-.573.412 0 .573-.115.573-.458 0-.39-.16-.458-1.031-.458h-1.031Z"
                    />
                    <Path
                      data-name="Path 11468"
                      d="M6.1 15c0 .39.16.458 1.146.458s1.146-.069 1.146-.458-.161-.458-1.146-.458S6.1 14.611 6.1 15Z"
                    />
                    <Path
                      data-name="Path 11469"
                      d="M9.61 15c0 .344.16.458.573.458s.573-.115.573-.458-.161-.458-.573-.458-.573.115-.573.458Z"
                    />
                    <Path
                      data-name="Path 11470"
                      d="M8.438 16.171c0 .344.16.458.573.458s.573-.115.573-.458-.161-.458-.573-.458-.573.115-.573.458Z"
                    />
                    <Path
                      data-name="Path 11471"
                      d="M11.954 16.171c0 .344.16.458.573.458s.573-.115.573-.458-.161-.458-.573-.458-.573.115-.573.458Z"
                    />
                    <Path
                      data-name="Path 11472"
                      d="M14.517 16.318c0 .458-.115.573-.573.573-.527 0-.573.069-.573 1.146 0 .985.069 1.146.458 1.146.344 0 .458-.16.458-.573 0-.458.115-.573.573-.573.527 0 .573-.069.573-1.146 0-.985-.069-1.146-.458-1.146-.344 0-.458.16-.458.573Z"
                    />
                    <Path
                      data-name="Path 11473"
                      d="M3.666 17.459c0 .412.115.573.458.573s.458-.16.458-.573-.116-.573-.458-.573-.458.16-.458.573Z"
                    />
                    <Path
                      data-name="Path 11474"
                      d="M7.104 17.53c0 .458-.115.573-.573.573s-.573.115-.573.573v.55l-2.91.069c-2.75.069-2.933.092-2.933.527s.183.458 4.652.527l4.629.046v2.292h3.437v-1.17c0-1.077-.046-1.146-.5-1.077a.638.638 0 0 0-.6.573.6.6 0 0 1-1.192-.046c0-.458-.115-.573-.573-.573s-.573-.115-.573-.573c0-.527-.069-.573-1.146-.573-1.054 0-1.146-.046-1.146-.55 0-.412.137-.573.527-.642a.638.638 0 0 0 .573-.6c.069-.412-.023-.5-.5-.5s-.599.116-.599.574Z"
                    />
                    <Path
                      data-name="Path 11475"
                      d="m9.665 17.979.069 1.1 1.1.069 1.077.069v-2.315H9.596Z"
                    />
                    <Path
                      data-name="Path 11476"
                      d="M14.53 19.801c0 .412.115.573.458.573s.458-.16.458-.573-.116-.573-.458-.573-.458.16-.458.573Z"
                    />
                    <Path
                      data-name="Path 11477"
                      d="M15.702 21.564c0 .985.069 1.146.458 1.146s.458-.16.458-1.146-.068-1.146-.458-1.146-.458.16-.458 1.146Z"
                    />
                    <Path
                      data-name="Path 11478"
                      d="M.092 22.072a20.5 20.5 0 0 0-.046 3.025c.137 4.377.573 4.766 5.225 4.766h2.864v-8.02l-3.964-.069c-3.369-.049-3.965 0-4.079.298Zm7.012 3.781v2.979H4.72c-3.346 0-3.437-.069-3.529-3.414l-.092-2.544h6Z"
                    />
                    <Path
                      data-name="Path 11479"
                      d="M2.521 25.848v1.6h3.437v-3.2H2.521Z"
                    />
                    <Path
                      data-name="Path 11480"
                      d="M14.53 23.314c0 .412.115.573.458.573s.458-.16.458-.573-.116-.573-.458-.573-.458.16-.458.573Z"
                    />
                    <Path
                      data-name="Path 11481"
                      d="M9.61 24.706c0 .344.16.458.573.458s.573-.115.573-.458-.161-.458-.573-.458-.573.115-.573.458Z"
                    />
                    <Path
                      data-name="Path 11482"
                      d="M13.358 24.706a.411.411 0 0 0 .458.458.411.411 0 0 0 .458-.458.411.411 0 0 0-.458-.458.411.411 0 0 0-.458.458Z"
                    />
                    <Path
                      data-name="Path 11483"
                      d="M15.694 24.706c0 .344.16.458.573.458.481 0 .573.115.573.687 0 .619-.069.687-.687.687-.573 0-.687-.092-.687-.573 0-.412-.115-.573-.458-.573s-.458.16-.458.573c0 .458-.115.573-.573.573-.527 0-.573.092-.573 1.031 0 .871.069 1.031.458 1.031.344 0 .458-.16.458-.573 0-.481.115-.573.687-.573.619 0 .687.069.687.687 0 .573-.092.687-.573.687-.458 0-.573.115-.573.573 0 .527.092.573 1.031.573h1.031v-1.26c0-1.237 0-1.26.687-1.26h.687v-3.206h-1.145c-.985 0-1.145.069-1.145.458Z"
                    />
                    <Path
                      data-name="Path 11484"
                      d="M10.792 26.994c0 1.558.023 1.6.573 1.6.527 0 .573-.069.573-1.146s.046-1.146.573-1.146c.412 0 .573-.115.573-.458 0-.39-.16-.458-1.146-.458h-1.146Z"
                    />
                    <Path
                      data-name="Path 11485"
                      d="M18.048 28.855c0 1.077.046 1.146.527 1.077.435-.069.5-.229.573-1.169.069-1.031.046-1.077-.5-1.077s-.6.069-.6 1.169Z"
                    />
                    <Path
                      data-name="Path 11486"
                      d="M9.657 29.331a.641.641 0 0 0 .6.6c.412.069.5-.023.5-.5s-.115-.6-.6-.6-.569.092-.5.5Z"
                    />
                    <Path
                      data-name="Path 11487"
                      d="M12.001 29.331a.641.641 0 0 0 .6.6c.412.069.5-.023.5-.5s-.115-.6-.6-.6-.569.092-.5.5Z"
                    />
                  </G>
                </Svg>
              }
              route={"QR"}
              state={"book"}
            />
            <Button
              icon={
                <Svg
                  xmlns="http://www.w3.org/2000/svg"
                  width={29.9}
                  height={30.908}
                >
                  <G
                    data-name="Group 419"
                    fill={
                      theme === "light"
                        ? Colors.theme1.green79
                        : Colors.theme1.white
                    }
                  >
                    <Path
                      data-name="Path 1864"
                      d="M1.694 1.694h5.081V0H0v6.775h1.694Zm0 0"
                    />
                    <Path
                      data-name="Path 1863"
                      d="M22.132 0v1.694h5.081v5.081h1.694V0Zm0 0"
                    />
                    <Path
                      data-name="Path 1862"
                      d="M27.213 27.214h-5.081v1.694h6.775v-6.775h-1.694Zm0 0"
                    />
                    <Path
                      data-name="Path 1861"
                      d="M1.694 22.133H0v6.775h6.775v-1.694H1.694Zm0 0"
                    />
                    <Textt
                      transform="translate(15 19)"
                      fontSize={14}
                      // fontFamily="regular"
                    >
                      <TSpan x={-8.841} y={0}>
                        {"AR"}
                      </TSpan>
                    </Textt>
                  </G>
                </Svg>
              }
              route={"AR"}
              state={"AR"}
            />
          </>
        ) : null}
        {headerOptions?.bookmark ? (
          bookmarkLoading ? (
            <ActivityIndicator
              size={20}
              color={
                theme === "light" ? Colors.theme1.green79 : Colors.theme1.white
              }
            />
          ) : isActiveBookmark ? (
            <Ionicons
              name="bookmark"
              style={tw("mr-2")}
              size={24}
              color={
                theme === "light" ? Colors.theme1.green79 : Colors.theme1.white
              }
              onPress={() =>
                headerOptions?.bookmarkItem?.contentId
                  ? deleteBookmark({
                      id: userFavoriteList.filter(
                        (object) =>
                          object.contentId ===
                          headerOptions.bookmarkItem?.contentId
                      )[0].id,
                    })
                  : deleteBookmark({
                      id: userFavoriteList.filter(
                        (object) =>
                          object.productId ===
                          headerOptions.bookmarkItem?.productId
                      )[0].id,
                    })
              }
            />
          ) : (
            <Ionicons
              name="bookmark-outline"
              style={tw("mr-2")}
              size={24}
              color={
                theme === "light" ? Colors.theme1.green79 : Colors.theme1.white
              }
              onPress={() =>
                headerOptions?.bookmarkItem?.contentId
                  ? addToBookmark({
                      contentId: headerOptions?.bookmarkItem?.contentId,
                    })
                  : addToBookmark({
                      productId: headerOptions?.bookmarkItem?.productId,
                    })
              }
            />
          )
        ) : null}
        {headerOptions?.menu ? (
          <Entypo
            name="dots-three-vertical"
            size={24}
            color={theme === "light" ? "#52796F" : Colors.theme1.white}
          />
        ) : null}
      </View>
    </View>
  );
};

const mapStateToProps = (state) => ({
  userFavoriteList: state.userFavorite.list,
  theme: state.publicApi.theme,
  bookmarkLoading: state.userFavorite.loading,
});

const mapDispatchToProps = {
  addToBookmark: userFavorite.add,
  deleteBookmark: userFavorite.del,
};

export default connect(mapStateToProps, mapDispatchToProps)(Navbar);
