import React, { useState } from "react";
import { TextInput, View, StyleSheet, Pressable } from "react-native";
import { connect } from "react-redux";
import tw from "tailwind-rn";
import { AntDesign } from "@expo/vector-icons";

//style
import Colors from "../constants/Colors";
import fontSize from "../constants/fontSize";

const Search = ({
  placeholder,
  textAlign,
  direction,
  onChange,
  value,
  theme,
}) => {
  const styles = StyleSheet.create({
    inputStyle: {
      fontSize: fontSize.tiny,
      color: theme === "light" ? Colors.theme1.gray2077 : Colors.theme1.white,
      borderWidth: 0.5,
      borderColor: Colors.theme1.gray20 + "88",
      paddingVertical: 10,
      paddingHorizontal: 10,
      direction: direction,
      textAlign: textAlign,
      backgroundColor:
        theme === "light" ? Colors.theme1.white : Colors.theme1.gray2077,
      fontFamily: "regular",
    },
  });
  return (
    <View style={[{ marginTop: 18 }, tw("w-full relative")]}>
      <TextInput
        style={[styles.inputStyle, tw("rounded-sm")]}
        onChangeText={(text) => onChange(text)}
        placeholder={placeholder}
        placeholderTextColor={
          theme === "light"
            ? Colors.theme1.gray20 + "88"
            : Colors.theme1.white + "aa"
        }
        value={value}
      />
      <Pressable style={tw("absolute left-3 top-3")}>
        <AntDesign name="search1" size={20} color="#52796F" />
      </Pressable>
    </View>
  );
};

const mapStateToProps = (state) => ({
  theme: state.publicApi.theme,
});

export default connect(mapStateToProps)(Search);

Search.defaultProps = {
  direction: "rtl",
  textAlign: "right",
};
