import React, { useState, useEffect } from "react";
import {
  SafeAreaView,
  ScrollView,
  StatusBar,
  LayoutAnimation,
  Platform,
  Dimensions,
  View,
} from "react-native";
import { connect } from "react-redux";
import { userProduct } from "../../redux/actions";

//components
import Navbar from "../../components/Navbar";
import Drawer from "../../components/Drawer";
import Book from "./components/Book";
import Empty from "../../components/Empty";

//style
import tw from "tailwind-rn";

const { height } = Dimensions.get("window");
const ios = Platform.OS === "ios";

function AR({ getArList, arList, mobile, theme }) {
  const [position, setPosition] = useState("100%");

  useEffect(() => {
    getArList();
    StatusBar.setBarStyle(
      `${theme === "light" ? "dark" : "light"}-content`,
      true
    );
  }, []);

  useEffect(() => {
    StatusBar.setBarStyle(
      `${theme === "light" ? "dark" : "light"}-content`,
      true
    );
  }, [theme]);

  const setBoxPosition = () => {
    LayoutAnimation.configureNext(LayoutAnimation.Presets.easeInEaseOut);
    setPosition(position === "100%" ? "0%" : "100%");
  };

  return (
    <SafeAreaView
      style={{
        paddingTop: Platform.OS === "android" ? StatusBar.currentHeight : 0,
        position: "relative",
        flex: 1,
      }}
    >
      <Navbar
        setBoxPosition={setBoxPosition}
        headerOptions={{
          logo: false,
          menu: false,
          hamburgerMenu: false,
          title: "واقعیت افزوده",
          bookmark: false,
          qr: false,
          back: true,
        }}
      />
      <Drawer setBoxPosition={setBoxPosition} position={position} />
      {arList?.length ? (
        <ScrollView
          style={{
            paddingHorizontal: 16,
            height: height,
          }}
          contentContainerStyle={{ paddingBottom: 60 }}
        >
          <View
            style={tw(
              `flex justify-between flex-wrap ${
                ios ? "flex-row-reverse" : "flex-row"
              }`
            )}
          >
            {arList?.map((book, index) => (
              <Book book={book} key={index} />
            ))}
          </View>
        </ScrollView>
      ) : (
        <Empty
          text="هیچ موردی برای شما وجود ندارد."
          buttonText={"رفتن به فروشگاه"}
          buttonAction={() => navigation.push("Products")}
        />
      )}
    </SafeAreaView>
  );
}

const mapStateToProps = (state) => ({
  arList: state.userProduct.arList,
  mobile: state.publicApi.mobile,
  theme: state.publicApi.theme
});

const mapDispatchToProps = {
  getArList: userProduct.arList,
};

export default connect(mapStateToProps, mapDispatchToProps)(AR);
