import React from "react";
import { View, Text, FlatList, Pressable } from "react-native";
import { connect } from "react-redux";
import { blog } from "../../../redux/actions";
import Svg, { Path } from "react-native-svg";

//style
import tw from "tailwind-rn";
import fontSize from "../../../constants/fontSize";
import Colors from "../../../constants/Colors";

export const Hashtags = ({ hashtags, theme, setHashtag, hashtag }) => {
  return (
    <View
      style={[
        tw("flex flex-row-reverse pl-3 rounded-full items-center w-full mb-7 mt-3"),
        {
          borderWidth: 2,
          borderColor: Colors.theme1.greenFF1 + (theme === "light" ? "" : "55"),
        },
      ]}
    >
      <Svg xmlns="http://www.w3.org/2000/svg" width={31.486} height={19.692}>
        <Path
          d="M29.012 2.475 16.628 14.859 11.91 7.782l-9.435 9.436"
          fill="none"
          stroke="#5db916"
          strokeLinecap="round"
          strokeLinejoin="round"
          strokeWidth={3.5}
        />
      </Svg>
      <FlatList
        showsHorizontalScrollIndicator={false}
        horizontal={true}
        inverted={true}
        style={[tw("flex flex-row mt-3 pb-3 mr-2")]}
        data={hashtags}
        renderItem={({ item }) => (
          <Hashtag
            hashtag={item}
            theme={theme}
            setHashtag={setHashtag}
            activeTag={hashtag}
          />
        )}
        keyExtractor={(item, index) => {
          return index;
        }}
      />
    </View>
  );
};

const Hashtag = ({ hashtag, theme, setHashtag, activeTag }) => {
  const active = React.useMemo(() => {
    return activeTag === hashtag;
  }, [hashtag, activeTag]);
  return (
    <Pressable
      onPress={() => (active ? setHashtag(null) : setHashtag(hashtag))}
    >
      <Text
        style={[
          tw("px-2 py-0.5 mx-1"),
          {
            fontFamily: "bold",
            fontSize: fontSize.sm,
            color:
              theme === "light"
                ? active
                  ? Colors.theme1.white
                  : Colors.theme1.gray20
                : Colors.theme1.white,
            backgroundColor: active ? Colors.theme1.greenCF : null,
          },
        ]}
      >
        {"#" + " " + hashtag}
      </Text>
    </Pressable>
  );
};

const mapStateToProps = (state) => ({
  hashtags: state.blog.hashtags,
  theme: state.publicApi.theme,
  hashtag: state.blog.hashtag,
});

const mapDispatchToProps = {
  setHashtag: blog.setHashtag,
};

export default connect(mapStateToProps, mapDispatchToProps)(Hashtags);
