import React, { useMemo, useEffect, useCallback } from "react";
import {
  ScrollView,
  Appearance,
  SafeAreaView,
  View,
  StatusBar,
  Platform,
} from "react-native";
import { connect } from "react-redux";
import { userProduct, comment, file, form } from "../../../redux/actions";
import onInput from "../../../utils/onInput";
import { asyncAwesomeAlert } from "../../../utils/AsyncWrappers";

//components
import CustomTextInput from "../../../components/CustomTextInput";
import CustomPressable from "../../../components/Pressable";
import Select from "../../../components/Select";
import Navbar from "../../../components/Navbar";

//style
import tw from "tailwind-rn";
import Colors from "../../../constants/Colors";
import fontSize from "../../../constants/fontSize";

export const Ticket = ({
  myProductList,
  status,
  ticket,
  getUserProductList,
  submit,
  upload,
  setTicket,
  grades,
  theme,
}) => {
  let opt = useMemo(() => {
    return ["واحد مورد نظر", "واحد فروش", "واحد فنی", "واحد محتوایی"];
  }, [status]);

  useEffect(() => {
    if (status) {
      getUserProductList();
    }
  }, []);

  const send = useCallback(async () => {
    if (!ticket?.unit) {
      asyncAwesomeAlert("", "واحد مورد نظر خود را وارد نکرده اید.", {
        showCancelButton: false,
      });
    } else if (!ticket?.subject) {
      asyncAwesomeAlert("", "موضوع پیام خود را وارد کنید.", {
        showCancelButton: false,
      });
    } else if (!ticket?.text) {
      asyncAwesomeAlert("", "متن پیام خود را وارد کنید.", {
        showCancelButton: false,
      });
    } else {
      const data = {
        fileId: null,
        text: ticket?.text,
        name: !status ? ticket?.name : status.firstName + " " + status.lastName,
        cellphone: !status ? ticket?.cellphone : status?.cellphone,
        unit: ticket?.unit,
        bookId: ticket?.bookId,
        subject: ticket?.subject,
        userId: status?.userId,
      };
      await submit(data);
    }
  }, [status, ticket]);

  return (
    <SafeAreaView
      style={{
        paddingTop: Platform.OS === "android" ? StatusBar.currentHeight : 0,
        position: "relative",
        flex: 1,
      }}
    >
      <Navbar
        headerOptions={{
          logo: false,
          menu: false,
          hamburgerMenu: false,
          title: "ارسال تیکت",
          bookmark: false,
          qr: false,
          back: true,
        }}
      />
      <ScrollView style={tw("flex-1 px-4 pt-4")}>
        {!status ? (
          <>
            <CustomTextInput
              label="نام و نام خانوادگی"
              name="name"
              onChange={(name, value) => setTicket({ name, value })}
              value={ticket?.name || ""}
              regex={(val) => val}
            />
            <CustomTextInput
              label="شماره تماس"
              name="cellphone"
              onChange={(name, value) => setTicket({ name, value })}
              value={ticket?.cellphone || ""}
              regex={(val) => onInput.phonenumber(val)}
              maxLength={11}
            />
          </>
        ) : null}
        <Select
          defaultValue={ticket?.unit || opt[0]}
          options={myProductList.length ? opt : opt.slice(0, 3)}
          name="unit"
          onChange={(name, value) => setTicket({ name, value })}
          width={"100%"}
        />
        {ticket?.unit === "واحد محتوایی" ? (
          <Select
            name="bookId"
            defaultValue={ticket?.subject}
            options={[
              ...new Set(
                myProductList?.map((item) => [
                  item?.product?.book?.id,
                  `${item?.product?.book.name} پایه ${
                    Object.values(grades)[item.product.book.gradeId]
                  }`,
                ]) || []
              ),
            ]}
            onChange={(name, value) => setTicket({ name, value })}
            width={"100%"}
          />
        ) : null}
        <CustomTextInput
          name="subject"
          onChange={(name, value) => setTicket({ name, value })}
          value={ticket?.subject || ""}
          regex={(val) => val}
          label="موضوع"
          textAlign={"right"}
        />
        <CustomTextInput
          name="text"
          onChange={(name, value) => setTicket({ name, value })}
          value={ticket?.text || ""}
          regex={(val) => val}
          label="متن پیام"
          multiline={true}
          textAlign={"right"}
        />
        <View style={tw("mt-4")}></View>
      </ScrollView>
      <View style={tw("w-full px-4")}>
        <CustomPressable
          title={"ارسال پیام"}
          backgroundColor={Colors.theme1.greenCF}
          color={"white"}
          border={{ color: "#196EC0", width: 0 }}
          width={"100%"}
          onPress={() => send()}
        />
      </View>
    </SafeAreaView>
  );
};

const mapStateToProps = (state) => ({
  isDark: state.publicApi.isDark,
  myProductList: state.userProduct.myList,
  status: state.user.status,
  ticket: state.form.ticket,
  grades: state.publicApi.grades,
  theme: state.publicApi.theme,
});

const mapDispatchToProps = {
  getUserProductList: userProduct.myList,
  submit: comment.add,
  upload: file.upload,
  setTicket: form.setTicket,
};

export default connect(mapStateToProps, mapDispatchToProps)(Ticket);
