import { View, Text, Pressable, Platform } from "react-native";
import React, { useCallback, useState } from "react";
import { connect } from "react-redux";

//style
import tw from "tailwind-rn";
import Colors from "../../../constants/Colors";
import fontSize from "../../../constants/fontSize";

const ios = Platform.OS === "ios";

const TransportDate = ({ transportDate, mobile, theme }) => {
  const [activeDate, setActiveDate] = useState(transportDate?.times[0]);

  const light = React.useMemo(() => {
    return theme === "light";
  }, [theme]);

  const Time = useCallback(({ time, active }) => {
    return (
      <Pressable
        style={[
          tw(`flex flex-row-reverse justify-between items-center w-full px-3 ${mobile ? "py-3" : "py-2"} rounded-sm mt-3`),
          {
            backgroundColor: light ? active
              ? Colors.theme1.greenCF + "15"
              : Colors.theme1.grayE3 + "44" : null,
            borderWidth: 1.5,
            borderColor: active
              ? Colors.theme1.greenCF
              : Colors.theme1.grayE3,
          },
        ]}
        onPress={() => setActiveDate(time)}
      >
        <Text
          style={{
            fontFamily: "regular",
            fontSize: mobile ? fontSize.tiny : fontSize.xl,
            color: active
              ? light ? Colors.theme1.gray20 : Colors.theme1.greenCF
              : light ? Colors.theme1.gray20 : Colors.theme1.white,
          }}
        >
          {time.time}
        </Text>
        
        <View style={tw("flex flex-row-reverse items-center")}>
            <View
              style={[
                tw(`${active ? "bg-green-600" : "bg-gray-600"}`),
                {
                  height: fontSize.base + 10,
                  width: 1,
                  marginLeft: 10,
                },
              ]}
            ></View>
            <Text
              style={{
                fontFamily: "regular",
                fontSize: mobile ? fontSize.sm : fontSize.base,
                color: active
                  ? light ? Colors.theme1.green20 : Colors.theme1.greenCF
                  : light ? Colors.theme1.gray20 : Colors.theme1.white,
              }}
            >
              تکمیل ظرفیت
            </Text>
          </View>
      </Pressable>
    );
  }, []);
  
  return (
    <View style={tw(`w-full ${mobile ? "mt-4" : "mt-4"}`)}>
      <Text
        style={{
          fontSize: mobile ? fontSize.base : fontSize.xl2,
          fontFamily: "bold",
          color: light ? Colors.theme1.green79 : Colors.theme1.white,
          textAlign : ios ? "right" : "auto",
        }}
      >
        زمان ارسال را انتخاب کنید.
      </Text>
      <View style={tw("p-0 m-0 flex  w-full")}>
        {transportDate?.times?.map((time, index) => (
          <Time time={time} key={index} active={time === activeDate} />
        ))}
      </View>
    </View>
  );
};

const mapStateToProps = (state) => ({
  mobile: state.publicApi.mobile,
  theme: state.publicApi.theme
});

const mapDispatchToProps = {};

export default connect(mapStateToProps, mapDispatchToProps)(TransportDate);
