import React from "react";
import { View, Text, Pressable } from "react-native";
import { Entypo } from "@expo/vector-icons";
import { useNavigation } from "@react-navigation/native";
import { connect } from "react-redux";

import fontSize from "../../../constants/fontSize";
import tw from "tailwind-rn";

//Color
import Colors from "../../../constants/Colors";

const Header = ({ title, route, mobile, theme, state = null }) => {
  const navigation = useNavigation();
  return (
    <View
      style={tw(
        `w-full flex flex-row-reverse justify-between ${mobile ? "" : "mb-2"}`
      )}
    >
      <Text
        style={[
          {
            color: theme === 'light' ? Colors.theme1.green79 : Colors.theme1.white,
            fontFamily: "demi",
            fontSize: mobile ? fontSize.lg : fontSize.xl2,
          },
        ]}
      >
        {title}
      </Text>
      {route ? (
        <Pressable
          onPress={() => navigation.navigate(route, state)}
          style={{ transform: [{ translateX: -fontSize.xl6 / 3 }] }}
        >
          <Entypo
            name="chevron-small-left"
            size={fontSize.xl6}
            color={theme === 'light' ? Colors.theme1.green79 : Colors.theme1.white}
          />
        </Pressable>
      ) : null}
    </View>
  );
};

const mapStateToProps = (state) => ({
  mobile: state.publicApi.mobile,
  theme: state.publicApi.theme,
});

export default connect(mapStateToProps)(Header);
