import {
  View,
  Text,
  Image,
  Pressable,
  FlatList,
  Platform,
  Linking,
} from "react-native";
import { connect } from "react-redux";

//components
import Progress from "../../../components/Progress";

//Color
import Colors from "../../../constants/Colors";
import tw from "tailwind-rn";
import fontSize from "../../../constants/fontSize";

const ios = Platform.OS === "ios";

function MyBooks({ books, grades, theme }) {
  return books?.filter((book) => book.condition >= 2).length ? (
    <View style={[tw("flex w-full mb-5")]}>
      <View
        style={[
          tw(`w-full flex  rounded-md pt-3 overflow-hidden`),
          {
            backgroundColor:
              theme === "light"
                ? Colors.theme1.greenCF + "0F"
                : Colors.theme1.greenCF + "11",
            borderColor:
              Colors.theme1.greenD9 + (theme === "light" ? "" : "77"),
            borderWidth: 1,
          },
        ]}
      >
        <Text
          style={[
            tw(`pr-4 ${ios ? "text-right" : ""} w-full`),
            {
              color:
                theme === "light" ? Colors.theme1.green79 : Colors.theme1.white,
              fontFamily: "demi",
              fontSize: fontSize.lg,
            },
          ]}
        >
          کتابهای من
        </Text>

        <FlatList
          showsHorizontalScrollIndicator={false}
          style={[tw("py-3")]}
          horizontal={true}
          inverted={true}
          data={books?.filter((book) => book.condition >= 2)}
          renderItem={({ item }) => (
            <Book book={item} grades={grades} theme={theme} />
          )}
          keyExtractor={(book) => book?.id}
        />
      </View>
    </View>
  ) : null;
}

const Book = ({ book, grades, theme }) => {
  const actions = {
    3: () =>
      Linking.openURL(`https://ar.dnvn.ir/lunch?id=${book.product.book.id}`),
    2: () =>
      Linking.openURL(`https://ar.dnvn.ir/lunch?id=${book.product.book.id}`),
    4: () => {},
  };
  return (
    <Pressable
      style={tw(`flex mr-4 ${ios ? "items-end" : ""}`)}
      onPress={actions[book.productType]}
    >
      <View style={{ height: 165 }}>
        <Image
          source={{
            uri: `https://dnvn.ir/api/v1/file/${book.product.book.fileIds}`,
          }}
          resizeMode="contain"
          style={[
            {
              width: 110,
              flex: 1,
            },
          ]}
        />
      </View>
      <Text
        style={[
          tw("mt-2 pr-1"),
          {
            color:
              theme === "light" ? Colors.theme1.gray20 : Colors.theme1.white,
            fontFamily: "bold",
            fontSize: fontSize.sm,
          },
        ]}
      >
        {book.product.book.name}
      </Text>
      <Text
        style={[
          tw("pr-1"),
          {
            color:
              theme === "light" ? Colors.theme1.gray20 : Colors.theme1.white,
            fontFamily: "light",
            fontSize: fontSize.sm,
          },
        ]}
      >
        {"پایه" + " " + grades[book.product.book.gradeId]}
      </Text>
      <Progress percent={60} alignItems={"items-end"} />
    </Pressable>
  );
};

const mapStateToProps = (state) => ({
  grades: state.publicApi.grades,
  theme: state.publicApi.theme,
});

export default connect(mapStateToProps)(MyBooks);
