import React from "react";
import {
  View,
  Text,
  FlatList,
  Image,
  Dimensions,
  TextInput,
  Platform,
  Appearance,
  KeyboardAvoidingView,
} from "react-native";
import { comment, userFactor } from "../../../redux/actions";
import { connect } from "react-redux";

//components
import Pressable from "../../../components/Pressable";
import Avatar from "../../../components/Avatar";

//assets
import tw from "tailwind-rn";
import fontSize from "../../../constants/fontSize";
import Colors from "../../../constants/Colors";

const { width } = Dimensions.get("window");
const ios = Platform.OS === "ios";

function Commnets({
  comments,
  addComment,
  productId,
  getFullList,
  orderFullList,
  theme,
}) {
  React.useEffect(() => {
    if (!orderFullList.length) {
      getFullList();
    }
  }, []);

  return (
    <View style={[tw("flex")]}>
      <FlatList
        showsHorizontalScrollIndicator={false}
        horizontal={true}
        inverted={true}
        style={{ marginTop: 20, paddingBottom: 10 }}
        data={comments}
        renderItem={({ item }) => <Comment comment={item} theme={theme} />}
        keyExtractor={(item) => item.id}
      />
      <AddComment addComment={addComment} productId={productId} theme={theme} />
    </View>
  );
}

const Comment = ({ comment, theme }) => {
  return (
    <View
      style={[
        tw("flex  rounded-md p-4 ml-2"),
        { width: width / 1.3, borderWidth: 1, borderColor: "#7070701a" },
      ]}
    >
      <View style={[tw("flex flex-row-reverse justify-between items-center")]}>
        <View style={tw("flex flex-row-reverse items-center")}>
          <Image
            source={comment.imageUrl}
            style={[tw("rounded-full"), { width: 35, height: 35 }]}
          />
          <Text
            style={[
              { fontSize: fontSize.sm, color: "#132F52", fontFamily: "bold" },
              ,
            ]}
          >
            {comment.name}
          </Text>
        </View>
        <View style={tw("flex flex-row items-center")}>
          <Text
            style={{
              fontSize: fontSize.xs,
              color: "#196EC0",
              fontFamily: "light",
            }}
          >
            18:20
          </Text>
          <View
            style={{
              backgroundColor: "#196EC055",
              height: 12,
              width: 1,
              marginHorizontal: 4,
            }}
          ></View>
          <Text
            style={{
              fontSize: fontSize.xs,
              color: "#196EC0",
              fontFamily: "light",
            }}
          >
            1400/08/19
          </Text>
        </View>
      </View>
      <Text
        style={[
          {
            fontSize: fontSize.sm,
            lineHeight: 20,
            color: "#132F52",
            fontFamily: "light",
          },
          tw("mt-2"),
        ]}
      >
        {comment.message}
      </Text>
    </View>
  );
};

const AddComment = ({ addComment, productId, theme, ...props }) => {
  const [commentForm, setCommentForm] = React.useState({
    title: "",
    text: "",
    fileId: null,
    productId: null,
  });

  const colorScheme = React.useMemo(() => {
    return Appearance.getColorScheme();
  }, [props.useless]);

  return (
    <KeyboardAvoidingView
      behavior={ios ? "padding" : "height"}
      style={[tw("flex items-end")]}
    >
      <Avatar source={null} size={width / 5.5} />
      <TextInput
        style={[
          tw("w-full mt-4 px-2 rounded-md"),
          {
            backgroundColor: theme === "light" ? Colors.theme1.grayF9 : null,
            color:
              theme === "light" ? Colors.theme1.gray20 : Colors.theme1.white,
            fontSize: fontSize.base,
            textAlign: "right",
            fontFamily: "light",
            borderWidth: 1,
            borderColor:
              theme === "light"
                ? Colors.theme1.grayE3
                : Colors.theme1.white + "55",
            height: fontSize.base + 30,
          },
        ]}
        value={comment.title}
        placeholder="عنوان نظر ..."
        onChangeText={(text) => setCommentForm({ ...commentForm, title: text })}
        placeholderTextColor={
          theme === "light"
            ? Colors.theme1.gray2077
            : Colors.theme1.white + "aa"
        }
      />
      <TextInput
        style={[
          tw("w-full mt-4 py-4 px-2 rounded-md h-40"),
          {
            backgroundColor: theme === "light" ? Colors.theme1.grayF9 : null,
            color:
              theme === "light" ? Colors.theme1.gray20 : Colors.theme1.white,
            fontSize: fontSize.tiny,
            textAlign: "right",
            fontFamily: "light",
            borderWidth: 1,

            borderColor:
              theme === "light"
                ? Colors.theme1.grayE3
                : Colors.theme1.white + "55",
          },
        ]}
        value={comment.text}
        multiline={true}
        textAlignVertical="top"
        placeholder="متن نظر ..."
        onChangeText={(text) => setCommentForm({ ...commentForm, text })}
        placeholderTextColor={
          theme === "light"
            ? Colors.theme1.gray2077
            : Colors.theme1.white + "aa"
        }
      />
      {commentForm.title && commentForm.text ? (
        <View style={tw("w-full mt-4")}>
          <Pressable
            title="ارسال نظر"
            backgroundColor={Colors.theme1.greenCF}
            color={Colors.theme1.white}
            border={{ width: 0, color: null }}
            width={"40%"}
            onPress={() => addComment(commentForm)}
          />
        </View>
      ) : null}
    </KeyboardAvoidingView>
  );
};

const mapStateToProps = (state) => ({
  orderFullList: state.userFactor.fullList,
  theme: state.publicApi.theme,
});

const mapDispatchToProps = {
  addComment: comment.add,
  getFullList: userFactor.fullList,
};

export default connect(mapStateToProps, mapDispatchToProps)(Commnets);
