import React, { useState, useEffect } from "react";

import {
  View,
  ScrollView,
  SafeAreaView,
  StatusBar,
  Dimensions,
  LayoutAnimation,
} from "react-native";
import { connect } from "react-redux";
import { book } from "../../redux/actions";

//components
import Drawer from "../../components/Drawer";
import Header from "./components/Header";
import Main from "./components/Main";
import Navbar from "../../components/Navbar";

//style

//variables
const {height} = Dimensions.get("window");

function Products({
  books,
  getBooks,
  grades,
  route,
  setFilterOptions,
  filterOptions,
}) {
  const [position, setPosition] = useState("100%");
  useEffect(() => {
    getBooks({ vod: true });
  }, []);

  const setBoxPosition = () => {
    LayoutAnimation.configureNext(LayoutAnimation.Presets.easeInEaseOut);
    setPosition(position === "100%" ? "0%" : "100%");
  };

  useEffect(() => {
    if (route?.params?.productType === "دوره ویدئویی") {
      setFilterOptions({ ...filterOptions, productType: "دوره ویدئویی" });
    }
  }, [route]);

  return (
    <SafeAreaView
      style={{
        paddingTop: Platform.OS === "android" ? StatusBar.currentHeight : 0,
        position: "relative",
      }}
    >
      <Navbar
        setBoxPosition={setBoxPosition}
        headerOptions={{
          logo: true,
          menu: false,
          hamburgerMenu: true,
          title: "",
          bookmark: false,
          qr: true,
          back: false,
        }}
      />
      <Drawer setBoxPosition={setBoxPosition} position={position} />
      <Header />
      <ScrollView contentContainerStyle={{ paddingBottom: height / 2 }}>
        <Main books={books} grades={grades} />
      </ScrollView>
    </SafeAreaView>
  );
}

const mapStateToProps = (state) => ({
  grades: state.publicApi.grades,
  books: state.book.list,
  filterOptions: state.book.filterOptions,
});

const mapDispatchToProps = {
  getBooks: book.list,
  setFilterOptions: book.setFilterOptions,
};

export default connect(mapStateToProps, mapDispatchToProps)(Products);

Products.defaultProps = {
  productTypes: ["کتاب فیزیکی", "کتاب دیجیتال", "ویدئوها", "اشتراک"],
};
