import React from "react";
import {
  View,
  Text,
  TouchableOpacity,
  Dimensions,
  ImageBackground,
  StatusBar,
} from "react-native";
import { useNavigation } from "@react-navigation/native";
import { BarCodeScanner } from "expo-barcode-scanner";
import { Entypo } from "@expo/vector-icons";
import { connect } from "react-redux";

//style
import tw from "tailwind-rn";
import Colors from "../../../../constants/Colors";

const { width, height } = Dimensions.get("screen");

//assets
import laptopImage from "../../assets/laptop.png";

function Scan({ theme, page }) {
  const navigation = useNavigation();
  const [hasPermission, setHasPermission] = React.useState(null);
  const [scanned, setScanned] = React.useState(false);

  React.useEffect(() => {
    (async () => {
      const { status } = await BarCodeScanner.requestPermissionsAsync();
      setHasPermission(status === "granted");
    })();
  }, []);

  const handleBarCodeScanned = React.useCallback(
    ({ type, data }) => {
      setScanned(true);
      if (page === "activation") {
        navigation.push("Activation", { data });
      } else {
        navigation.push("QRContent", { data });
      }
    },
    [page, scanned]
  );

  return (
    <ImageBackground
      source={laptopImage}
      resizeMode="cover"
      style={[tw("w-full"), { height: height - StatusBar.currentHeight }]}
    >
      <View
        style={tw(
          "flex-1 flex  justify-evenly items-center  bg-gray-800 bg-opacity-80"
        )}
      >
        <View style={{ width: height / 2.5, height: height / 2.5 }}>
          {hasPermission ? (
            <BarCodeScanner
              onBarCodeScanned={scanned ? undefined : handleBarCodeScanned}
              style={{ width: "100%", height: "100%" }}
            />
          ) : null}
        </View>

        {/* {scanned && ( */}
        <TouchableOpacity
          onPress={() => navigation.goBack()}
          style={[
            tw("py-2.5 rounded-full flex justify-center flex-row items-center"),
            {
              width: height / 3.5,
              borderWidth: 1,
              borderColor: Colors.theme1.greenCF,
            },
          ]}
        >
          <Entypo
            name="back"
            size={width / 27}
            style={{ marginRight: 5, color: Colors.theme1.greenCF }}
          />
          <Text
            style={[
              {
                color: Colors.theme1.greenCF,
                fontSize: width / 27,
                fontFamily: "regular",
              },
            ]}
          >
            بازگشت
          </Text>
        </TouchableOpacity>
      </View>
      {/* )} */}
    </ImageBackground>
  );
}

const mapStateToProps = (state) => ({
  theme: state.publicApi.theme,
});

export default connect(mapStateToProps)(Scan);
