import React from "react";
import { View, Text, Image, Dimensions } from "react-native";
import Tab from "../Tab";

//style
import tw from "tailwind-rn";
import Colors from "../../../constants/Colors";
import fontSize from "../../../constants/fontSize";

const { height, width } = Dimensions.get("window");

export default function Content({ data, grades, theme }) {
  const light = React.useMemo(() => {
    return theme === 'light';
  },[theme]);
  return (
    <View style={tw("flex-1 flex  px-4 pb-20")}>
      <View style={tw("flex flex-1 ")}>
        <View style={tw("flex w-full flex-row-reverse justify-between")}>
          <View style={tw("flex flex-row-reverse flex-1")}>
            <Image
              source={{ uri: "https://dnvn.ir/api/v1/file/2105" }}
              style={[{ height: height / 4.5, flex: 1 }, tw("rounded-md")]}
              resizeMode="contain"
            />
            <View style={tw("flex pr-2")}>
              <Text
                style={{
                  fontFamily: "bold",
                  fontSize: fontSize.lg,
                  color: light ? Colors.theme1.green79 : Colors.theme1.white,
                  textAlign: "right",
                }}
              >
                {data.book.name}
              </Text>
              <Text
                style={[
                  tw("mt-1"),
                  {
                    fontFamily: "regular",
                    fontSize: fontSize.tiny,
                    color: light ? Colors.theme1.green79 : Colors.theme1.white,
                    textAlign: "right",
                  },
                ]}
              >
                {"پایه" + " " + grades[data.book.gradeId]}
              </Text>
              <Text
                style={[
                  tw("mt-1"),
                  {
                    fontFamily: "regular",
                    fontSize: fontSize.tiny,
                    color: light ? Colors.theme1.green79 : Colors.theme1.white,
                    textAlign: "right",
                  },
                ]}
              >{`شما در حال مشاهده صفحه ${data.qr.pageNumber} هستید.`}</Text>
            </View>
          </View>
        </View>
      </View>
      <Tab
        data={{
          voice: data.qr.content.filter((obj) => obj.type === "voice")[0],
          video: data.qr.content.filter((obj) => obj.type === "video")[0],
          pdf: data.qr.content.filter((obj) => obj.type === "pdf")[0],
          ppt: data.qr.content.filter((obj) => obj.type === "ppt")[0],
          links: data.qr.content.filter((obj) => obj.type === "links")[0],
        }}
        theme={theme}
      />
    </View>
  );
}

Content.defaultProps = {
  data: {
    name: "ریاضیات گسسته خیلی پیشرفته",
    grade: "پایه هفتم ابتدایی",
    page: "67",
    percent: "62",
    voice: { name: "استاد رضایی: فصل پنجم توضیح در مورد آتش فشان ها", file: 1 },
    video: { name: "ویدئوی آزمایش آتشفشان سرکه ای", file: 1 },
    pdf: { name: "فایل پاورپوینت ارائه درس آتشفشان ها", file: 1 },
    ppt: { name: "فایل پاورپوینت ارائه درس آتشفشان ها", file: 1 },
    links: [
      "وبسایت آموزشی دانوین",
      "وبسایت رسمی مدیریت راهبردی کشور",
      "سازمان تبلیغات صنایع سبک ",
    ],
  },
};
