import React, { useState } from "react";
import { View, Text, TouchableOpacity, Dimensions } from "react-native";
import { connect } from "react-redux";

//components
import Voice from "../Content/Voice";
import Video from "../Content/Video";
import PPT from "../Content/PPT";
import PDF from "../Content/PDF";
import Links from "../Content/Links";

//assets
import tw from "tailwind-rn";
import Colors from "../../../constants/Colors";
import fontSize from "../../../constants/fontSize";

const { width } = Dimensions.get("window");

function Tab({ data, theme }) {
  const [dataType, setDataType] = useState("all");

  const light = React.useMemo(() => {
    return theme === "light";
  }, [theme]);

  return (
    <View
      style={[
        tw("w-full flex  rounded-md overflow-hidden mt-4"),
        { borderWidth: 1, borderColor: Colors.theme1.greenBA + "aa" },
      ]}
    >
      <View style={tw("w-full flex flex-row-reverse justify-between")}>
        <TouchableOpacity
          onPress={() => setDataType("all")}
          style={[
            tw("py-2 w-1/6"),
            {
              borderBottomWidth: dataType === "all" ? 0 : 1,
              borderColor: Colors.theme1.greenBA + "aa",
              backgroundColor:
                dataType === "all"
                  ? Colors.theme1.greenCF
                  : light
                  ? Colors.theme1.white
                  : Colors.theme1.dark,
            },
          ]}
        >
          <Text
            style={{
              fontSize: fontSize.xs,
              fontFamily: dataType === "all" ? "regular" : "light",
              textAlign: "center",
              color:
                dataType === "all"
                  ? Colors.theme1.white
                  : light
                  ? Colors.theme1.gray20
                  : Colors.theme1.white,
            }}
          >
            تمامی محتوا
          </Text>
        </TouchableOpacity>
        <TouchableOpacity
          onPress={() => setDataType("voice")}
          style={[
            tw("py-2 w-1/6"),
            {
              borderBottomWidth: dataType === "voice" ? 0 : 1,
              borderColor: Colors.theme1.greenBA + "aa",
              backgroundColor:
                dataType === "voice"
                  ? Colors.theme1.greenCF
                  : light
                  ? Colors.theme1.white
                  : Colors.theme1.dark,
            },
          ]}
        >
          <Text
            style={{
              fontSize: fontSize.xs,
              fontFamily: dataType === "voice" ? "bold" : "light",
              textAlign: "center",
              color:
                dataType === "voice"
                  ? Colors.theme1.white
                  : light
                  ? Colors.theme1.gray20
                  : Colors.theme1.white,
            }}
          >
            صوت
          </Text>
        </TouchableOpacity>
        <TouchableOpacity
          onPress={() => setDataType("video")}
          style={[
            tw("py-2 w-1/6"),
            {
              borderBottomWidth: 1,
              borderColor: Colors.theme1.greenBA + "aa",
              backgroundColor:
                dataType === "video"
                  ? Colors.theme1.greenCF
                  : light
                  ? Colors.theme1.white
                  : Colors.theme1.dark,
            },
          ]}
        >
          <Text
            style={{
              fontSize: fontSize.xs,
              fontFamily: dataType === "video" ? "bold" : "light",
              textAlign: "center",
              color:
                dataType === "video"
                  ? Colors.theme1.white
                  : light
                  ? Colors.theme1.gray20
                  : Colors.theme1.white,
            }}
          >
            ویدئو
          </Text>
        </TouchableOpacity>
        <TouchableOpacity
          onPress={() => setDataType("pdf")}
          style={[
            tw("py-2 w-1/6"),
            {
              borderBottomWidth: 1,
              borderColor: Colors.theme1.greenBA + "aa",
              backgroundColor:
                dataType === "pdf"
                  ? Colors.theme1.greenCF
                  : light
                  ? Colors.theme1.white
                  : Colors.theme1.dark,
            },
          ]}
        >
          <Text
            style={{
              fontSize: fontSize.xs,
              fontFamily: dataType === "pdf" ? "bold" : "light",
              textAlign: "center",
              color:
                dataType === "pdf"
                  ? Colors.theme1.white
                  : light
                  ? Colors.theme1.gray20
                  : Colors.theme1.white,
            }}
          >
            پی دی اف
          </Text>
        </TouchableOpacity>
        <TouchableOpacity
          onPress={() => setDataType("ppt")}
          style={[
            tw("py-2 w-1/6"),
            {
              borderBottomWidth: 1,
              borderColor: Colors.theme1.greenBA + "aa",
              backgroundColor:
                dataType === "ppt"
                  ? Colors.theme1.greenCF
                  : light
                  ? Colors.theme1.white
                  : Colors.theme1.dark,
            },
          ]}
        >
          <Text
            style={{
              fontSize: fontSize.xs,
              fontFamily: dataType === "ppt" ? "bold" : "light",
              textAlign: "center",
              color:
                dataType === "ppt"
                  ? Colors.theme1.white
                  : light
                  ? Colors.theme1.gray20
                  : Colors.theme1.white,
            }}
          >
            پاور پوینت
          </Text>
        </TouchableOpacity>
        <TouchableOpacity
          onPress={() => setDataType("links")}
          style={[
            tw("py-2 w-1/6"),
            {
              borderBottomWidth: 1,
              borderColor: Colors.theme1.greenBA + "aa",
              backgroundColor:
                dataType === "links"
                  ? Colors.theme1.greenCF
                  : light
                  ? Colors.theme1.white
                  : Colors.theme1.dark,
            },
          ]}
        >
          <Text
            style={{
              fontSize: fontSize.xs,
              fontFamily: dataType === "links" ? "bold" : "light",
              textAlign: "center",
              color:
                dataType === "links"
                  ? Colors.theme1.white
                  : light
                  ? Colors.theme1.gray20
                  : Colors.theme1.white,
            }}
          >
            لینک ها
          </Text>
        </TouchableOpacity>
      </View>
      <View style={tw("flex  w-full p-4")}>
        {dataType === "all" ? (
          <>
            {data.voice ? <Voice data={data.voice} theme={theme} /> : null}
            {data.video ? <Video data={data.video} theme={theme} /> : null}
            {data.ppt ? <PPT data={data.ppt} theme={theme} /> : null}
            {data.pdf ? <PDF data={data.pdf} theme={theme} /> : null}
            {data.links ? <Links data={data.links} theme={theme} /> : null}
          </>
        ) : null}
        {dataType === "voice" ? (
          <>
            {data.voice ? (
              <Voice data={data.voice} theme={theme} />
            ) : (
              <Text
                style={{
                  fontSize: fontSize.tiny,
                  color: light ? Colors.theme1.gray2077 : Colors.theme1.white,
                  fontFamily: "light",
                  textAlign: "right",
                }}
              >
                فایل صدا یافت نشد.
              </Text>
            )}
          </>
        ) : null}
        {dataType === "video" ? (
          <>
            {data.video ? (
              <Video data={data.video} theme={theme} />
            ) : (
              <Text
                style={{
                  fontSize: fontSize.tiny,
                  color: light ? Colors.theme1.gray2077 : Colors.theme1.white,
                  fontFamily: "light",
                  textAlign: "right",
                }}
              >
                فایل تصویری یافت نشد.
              </Text>
            )}
          </>
        ) : null}
        {dataType === "ppt" ? (
          <>
            {data.ppt ? (
              <PPT data={data.ppt} theme={theme} />
            ) : (
              <Text
                style={{
                  fontSize: fontSize.tiny,
                  color: light ? Colors.theme1.gray2077 : Colors.theme1.white,
                  fontFamily: "light",
                  textAlign: "right",
                }}
              >
                فایل پاورپوینت یافت نشد.
              </Text>
            )}
          </>
        ) : null}
        {dataType === "pdf" ? (
          <>
            {data.pdf ? (
              <PDF data={data.pdf} theme={theme} />
            ) : (
              <Text
                style={{
                  fontSize: fontSize.tiny,
                  color: light ? Colors.theme1.gray2077 : Colors.theme1.white,
                  fontFamily: "light",
                  textAlign: "right",
                }}
              >
                فایل پی دی اف یافت نشد.
              </Text>
            )}
          </>
        ) : null}
        {dataType === "links" ? (
          <>
            {data.links ? (
              <Links data={data.links} theme={theme} />
            ) : (
              <Text
                style={{
                  fontSize: fontSize.tiny,
                  color: light ? Colors.theme1.gray2077 : Colors.theme1.white,
                  fontFamily: "light",
                  textAlign: "right",
                }}
              >
                لینکی پیدا نشد.
              </Text>
            )}
          </>
        ) : null}
      </View>
    </View>
  );
}

const mapStateToProps = (state) => ({
  theme: state.publicApi.theme,
});

export default connect(mapStateToProps)(Tab);
