import React, { useState, useEffect } from "react";
import {
  StyleSheet,
  ScrollView,
  SafeAreaView,
  Dimensions,
  StatusBar,
} from "react-native";
import { connect } from "react-redux";
import { qr } from "../../redux/actions";
import Content from "./Content";
import Navbar from "../../components/Navbar";

//style
import tw from 'tailwind-rn';

const {height} = Dimensions.get("window");

function QRContent({ route, getQrData, data, grades, theme }) {
  useEffect(() => {
    getQrData({ tail: route.params.data });
  }, []);

  return (
    <SafeAreaView
      style={{
        paddingTop: Platform.OS === "android" ? StatusBar.currentHeight : 0,
        height: height,
      }}
    >
      <Navbar
        headerOptions={{
          logo: false,
          menu: false,
          hamburgerMenu: false,
          title: "",
          bookmark: false,
          qr: false,
          back: true,
        }}
      />
      <ScrollView
      >
        {data ? <Content data={data} grades={grades} theme={theme} /> : null}
      </ScrollView>
    </SafeAreaView>
  );
}

const mapStateToProps = (state) => ({
  data: state.qr.list,
  grades : state.publicApi.grades,
  theme: state.publicApi.theme,
});

const mapDispatchToProps = {
  getQrData: qr.info,
};

export default connect(mapStateToProps, mapDispatchToProps)(QRContent);
