import {
  View,
  Text,
  ScrollView,
  Platform,
  StyleSheet,
  SafeAreaView,
  StatusBar,
  Dimensions,
  Pressable,
} from "react-native";
import { connect } from "react-redux";
import React from "react";

//components
import Navbar from "../../components/Navbar";

//style
import fontSize from "../../constants/fontSize";
import tw from "tailwind-rn";
import Colors from "../../constants/Colors";

//variables
const ios = Platform.OS === "ios";
const { width } = Dimensions.get("window");

const Rules = ({ route, mobile, theme }) => {
  const [active, setActive] = React.useState(0);
  const styles = React.useMemo(() => {
    return StyleSheet.create({
      contentContainerStyle: {
        paddingBottom: 100,
      },
      container: {
        flexDirection: "column",
        paddingVertical: 5,
        paddingHorizontal: 16,
      },
    });
  }, [route]);

  const items = React.useMemo(() => {
    return [
      {
        title: "آیا استفاده از سامانه دانوین هزینه دارد؟",
        description:
          "لورم ایپسوم متن ساختگی با تولید سادگی نامفهوم از صنعت چاپ، و با استفاده از طراحان گرافیک است، چاپگرها و متون بلکه روزنامه و مجله در ستون و سطرآنچنان که لازم است، و برای شرایط فعلی تکنولوژی مورد نیاز، و کاربردهای متنوع با هدف بهبود ابزارهای کاربردی می باشد  ",
      },
      {
        title: "چگونه می توان در سامانه عضو شد؟",
        description:
          "لورم ایپسوم متن ساختگی با تولید سادگی نامفهوم از صنعت چاپ، و با استفاده از طراحان گرافیک است، چاپگرها و متون بلکه روزنامه و مجله در ستون و سطرآنچنان که لازم است، و برای شرایط فعلی تکنولوژی مورد نیاز، و کاربردهای متنوع با هدف بهبود ابزارهای کاربردی می باشد  ",
      },
      {
        title: "چگونه می توان در سامانه عضو شد؟",
        description:
          "لورم ایپسوم متن ساختگی با تولید سادگی نامفهوم از صنعت چاپ، و با استفاده از طراحان گرافیک است، چاپگرها و متون بلکه روزنامه و مجله در ستون و سطرآنچنان که لازم است، و برای شرایط فعلی تکنولوژی مورد نیاز، و کاربردهای متنوع با هدف بهبود ابزارهای کاربردی می باشد  ",
      },
      {
        title: "چگونه می توان در سامانه عضو شد؟",
        description:
          "لورم ایپسوم متن ساختگی با تولید سادگی نامفهوم از صنعت چاپ، و با استفاده از طراحان گرافیک است، چاپگرها و متون بلکه روزنامه و مجله در ستون و سطرآنچنان که لازم است، و برای شرایط فعلی تکنولوژی مورد نیاز، و کاربردهای متنوع با هدف بهبود ابزارهای کاربردی می باشد  ",
      },
    ];
  }, [route]);

  return (
    <SafeAreaView
      style={{
        paddingTop: Platform.OS === "android" ? StatusBar.currentHeight : 0,
        position: "relative",
      }}
    >
      <Navbar
        headerOptions={{
          logo: false,
          menu: false,
          hamburgerMenu: false,
          title: "شرایط، قوانین استفاده و راهنما",
          bookmark: false,
          qr: false,
          back: true,
        }}
      />
      <ScrollView
        contentContainerStyle={styles.contentContainerStyle}
        style={styles.container}
      >
        <Switch theme={theme} active={active} setActive={setActive} />
        <Text
          numberOfLines={1}
          adjustsFontSizeToFit
          style={[
            tw("text-center my-3 p-2 rounded-sm"),
            {
              fontFamily: "bold",
              fontSize: fontSize.sm,
              color: Colors.theme1.redC0,
              backgroundColor: theme === 'light' ? Colors.theme1.redFF : null,
              borderWidth : theme === 'light' ? 0 : 1,
              borderColor : Colors.theme1.redC0
            },
          ]}
        >
          شما در حال مشاهده شرایط و قوانین استفاده از سامانه هستید
        </Text>
        {items.map((rule, index) => (
          <Rule rule={rule} key={index} theme={theme} />
        ))}
      </ScrollView>
    </SafeAreaView>
  );
};

const Switch = ({ theme, active, setActive }) => {
  return (
    <View
      style={[
        tw("w-full flex flex-row"),
        {
          borderWidth: 1,
          borderColor:
            theme === "light" ? Colors.theme1.green79 : Colors.theme1.greenCF,
        },
      ]}
    >
      <Pressable
        style={[
          tw("flex-1 py-3 flex flex-row justify-center"),
          {
            backgroundColor: active
              ? theme === "light"
                ? Colors.theme1.green79 + "11"
                : Colors.theme1.greenCF + "22"
              : "transparent",
          },
        ]}
        onPress={() => setActive(1)}
      >
        <Text
          style={{
            fontFamily: "regular",
            fontSize: fontSize.tiny,
            color:
              theme === "light" ? Colors.theme1.green79 : Colors.theme1.greenCF,
          }}
        >
          راهنمای استفاده
        </Text>
      </Pressable>
      <View style={[tw("w-px h-full")]}></View>
      <Pressable
        style={[
          tw("flex-1 py-3 flex flex-row justify-center"),
          {
            backgroundColor: !active
              ? theme === "light"
                ? Colors.theme1.green79 + "11"
                : Colors.theme1.greenCF + "22"
              : "transparent",
          },
        ]}
        onPress={() => setActive(0)}
      >
        <Text
          style={{
            fontFamily: "regular",
            fontSize: fontSize.tiny,
            color:
              theme === "light" ? Colors.theme1.green79 : Colors.theme1.greenCF,
          }}
        >
          شرایط و قوانین
        </Text>
      </Pressable>
    </View>
  );
};

const Rule = ({ rule, theme }) => {
  return (
    <View style={tw("flex mb-3")}>
      <Text
        style={[
          tw("mb-1 p-2 rounded-sm"),
          {
            fontFamily: "bold",
            fontSize: fontSize.sm,
            color:
              theme === "light" ? Colors.theme1.green79 : Colors.theme1.greenCF,
            backgroundColor:
              theme === "light" ? Colors.theme1.green79 + "11" : null,
            borderWidth: theme === "light" ? 0 : 1,
            borderColor: Colors.theme1.greenCF + "55",
            textAlign: "right",
          },
        ]}
      >
        {rule.title}
      </Text>
      <Text
        style={[
          tw("p-2 rounded-sm leading-6"),
          {
            fontFamily: "regular",
            fontSize: fontSize.sm,
            color:
              theme === "light" ? Colors.theme1.gray20 : Colors.theme1.white,
            textAlign: "right",
          },
        ]}
      >
        {rule.description}
      </Text>
    </View>
  );
};

const mapStateToProps = (state) => ({
  mobile: state.publicApi.mobile,
  theme: state.publicApi.theme,
});

export default connect(mapStateToProps)(Rules);
