import React from "react";
import {
  View,
  Text,
  Image,
  Dimensions,
  Pressable,
  ActivityIndicator,
  Platform,
} from "react-native";
import { connect } from "react-redux";
import { userProduct } from "../../../redux/actions";
import separate from "../../../utils/separate";
import { AntDesign } from "@expo/vector-icons";

//style
import Colors from "../../../constants/Colors";
import fontSize from "../../../constants/fontSize";
import tw from "tailwind-rn";

const width = Dimensions.get("window").width;
const ios = Platform.OS === "ios";

function Product({
  product,
  grades,
  pushToCart,
  loading,
  mobile,
  theme,
  addActionFlag,
  getList,
}) {
  const [selectedProduct, setSelectedProduct] = React.useState(null);

  const types = {
    1: "نسخه دیجیتال",
    2: "نسخه فیزیکی",
    4: "نسخه ویدئویی",
  };

  const submit = async (action) => {
    setSelectedProduct(product?.productId);
    await action();
  };

  React.useEffect(() => {
    if (!loading) {
      setSelectedProduct(null);
    }
  }, [loading]);

  return product ? (
    <View
      style={[
        tw(
          `flex justify-between py-2 ${ios ? "flex-row" : "flex-row-reverse"}`
        ),
        {
          borderBottomWidth: 1,
          borderColor: Colors.theme1.grayE3 + (theme === 'light' ? "" : "55"),
          direction: "rtl",
        },
      ]}
    >
      <View style={tw(`flex ${ios ? "flex-row" : "flex-row-reverse"}`)}>
        <Image
          source={{
            uri:
              "https://dnvn.ir/api/v1/file/" + product?.product?.book?.fileIds,
          }}
          style={[
            tw(""),
            {
              width: mobile ? width / 5 : width / 7,
              height: ((mobile ? width / 5 : width / 7) * 4) / 2.8,
            },
          ]}
        />
        <View
          style={tw(`flex   ${ios ? "items-start pl-3" : "items-end pr-2"}`)}
        >
          <Text
            style={{
              fontSize: mobile ? fontSize.lg : fontSize.xl4,
              color:
                theme === "light" ? Colors.theme1.green79 : Colors.theme1.white,
              marginBottom: 5,
              fontFamily: "bold",
            }}
          >
            {product?.product?.book?.name || " "}
          </Text>
          <Text
            style={{
              fontSize: mobile ? fontSize.sm : fontSize.lg,
              color:
                theme === "light"
                  ? Colors.theme1.gray2077
                  : Colors.theme1.white,
              marginBottom: 3,
              fontFamily: "regular",
            }}
          >
            {"پایه" + " " + grades[product?.product?.book?.gradeId] || " "}
          </Text>
          <Text
            style={{
              fontSize: mobile ? fontSize.sm : fontSize.lg,
              color:
                theme === "light"
                  ? Colors.theme1.gray2077
                  : Colors.theme1.white,
              fontFamily: "regular",
            }}
          >
            {types[product?.productType]}
          </Text>
          <View
            style={tw(
              `flex items-center justify-center mt-4 ${
                ios ? "flex-row-reverse" : "flex-row"
              }`
            )}
          >
            <Text
              style={[
                {
                  fontSize: mobile ? fontSize.xs : fontSize.tiny,
                  fontFamily: "regular",
                  color:
                    theme === "light"
                      ? Colors.theme1.gray20
                      : Colors.theme1.white,
                },
              ]}
            >
              {" " + "تومان"}
            </Text>
            <Text
              style={[
                {
                  fontSize: mobile ? fontSize.lg : fontSize.xl,
                  fontFamily: "regular",
                  color:
                    theme === "light"
                      ? Colors.theme1.gray20
                      : Colors.theme1.white,
                },
              ]}
            >
              {separate(product?.product?.price) || " "}
            </Text>
          </View>
        </View>
      </View>
      <View
        style={tw(`flex  justify-between ${ios ? "items-end" : "items-start"}`)}
      >
        <AntDesign
          name="close"
          size={mobile ? 20 : 30}
          color={Colors.theme1.redFF1}
          onPress={() =>
            submit(
              pushToCart(
                {
                  productId: product?.productId,
                  userId: product?.userId,
                  count: product?.productType === 1 ? -1 : -product?.count,
                },
                {},
                { id: product?.factorId }
              )
            )
          }
        />
        <View style={tw("flex  items-center mt-2")}>
          <View
            style={tw(
              `flex items-center mb-3 ${ios ? "flex-row" : "flex-row-reverse"}`
            )}
          >
            <Pressable
              onPress={() =>
                submit(
                  pushToCart({
                    productId: product?.productId,
                    userId: product?.userId,
                    count: 1,
                  })
                )
              }
              style={[
                tw(
                  `rounded-md py-0 flex flex-row justify-center items-center border ${
                    mobile ? "px-2" : "px-3"
                  }`
                ),
                {
                  borderColor: Colors.theme1.greenCF,
                },
              ]}
            >
              <Text
                style={{
                  fontSize: mobile ? fontSize.xl : fontSize.xl4,
                  color: Colors.theme1.greenCF,
                  fontFamily: "light",
                }}
              >
                +
              </Text>
            </Pressable>
            {loading && selectedProduct === product?.productId ? (
              <ActivityIndicator
                style={tw("mx-2")}
                size="small"
                color={Colors.theme1.greenBA}
              />
            ) : (
              <Text
                style={[
                  tw("mx-2.5"),
                  {
                    fontSize: fontSize.xl6,
                    color: Colors.theme1.greenBA,
                    fontFamily: "bold",
                  },
                ]}
              >
                {product?.count}
              </Text>
            )}

            <Pressable
              onPress={() =>
                submit(
                  pushToCart({
                    productId: product?.productId,
                    userId: product?.userId,
                    count: -1,
                  })
                )
              }
              style={[
                tw(
                  `rounded-md py-0  flex flex-row justify-center items-center border ${
                    mobile ? "px-2.5" : "px-3.5"
                  }`
                ),
                {
                  borderColor: Colors.theme1.greenCF,
                },
              ]}
            >
              <Text
                style={{
                  fontSize: mobile ? fontSize.xl : fontSize.xl4,
                  color: Colors.theme1.greenCF,
                  fontFamily: "bold",
                }}
              >
                -
              </Text>
            </Pressable>
          </View>
          <View
            style={tw(
              `flex items-center justify-center ${
                ios ? "flex-row-reverse" : "flex-row"
              }`
            )}
          >
            <Text
              style={[
                {
                  fontSize: fontSize.sm,
                  fontFamily: "regular",
                  color:
                    theme === "light"
                      ? Colors.theme1.gray20
                      : Colors.theme1.white,
                },
              ]}
            >
              {" " + "تومان"}
            </Text>
            <Text
              style={[
                {
                  fontSize: mobile ? fontSize.xl : fontSize.xl4,
                  fontFamily: "regular",
                  color:
                    theme === "light"
                      ? Colors.theme1.gray20
                      : Colors.theme1.white,
                },
              ]}
            >
              {separate(product?.product?.price * product?.count) || " "}
            </Text>
          </View>
        </View>
      </View>
    </View>
  ) : null;
}

const mapStateToProps = (state) => ({
  grades: state.publicApi.grades,
  mobile: state.publicApi.mobile,
  theme: state.publicApi.theme,
  addActionFlag: state.userProduct.addActionFlag,
});

const mapDispatchToProps = {
  pushToCart: userProduct.add,
  getList: userProduct.list,
};

export default connect(mapStateToProps, mapDispatchToProps)(Product);
