import React, { useEffect } from "react";
import {
  View,
  Image,
  ActivityIndicator,
  Dimensions,
  BackHandler,
  StatusBar,
} from "react-native";
import AsyncStorage from "@react-native-async-storage/async-storage";
import { connect } from "react-redux";
import { blog, book, userProduct, publicApi } from "../../redux/actions";
import { useIsFocused, useNavigation } from "@react-navigation/native";

import Logo from "../../assets/images/logo.png";

const { width } = Dimensions.get("window");

function Splash({
  isLogin,
  blogs,
  getBlogs,
  books,
  getBooks,
  userProducts,
  getUserProducts,
  setIsDark,
  theme,
}) {
  const navigation = useNavigation();
  const isFocused = useIsFocused();
  const [out, setOut] = React.useState(false);
  React.useEffect(() => {
    StatusBar.setBarStyle(
      `${theme === "light" ? "dark" : "light"}-content`,
      true
    );
  }, [theme]);

  const getTheme = async () => {
    const theme = await AsyncStorage.getItem("theme");
    return theme;
  }

  useEffect(() => {
    
    //set theme
    if (isLogin !== null) {
      if (isLogin === false) {
        setOut(true);
        navigation.navigate("Login");
      } else {
        if (blogs.length === 0) {
          getBlogs();
        } else if (books.length === 0) {
          getBooks({ vod: true });
        } else if (userProducts.length === 0) {
          getUserProducts();
        } else {
          setOut(true);
          navigation.navigate("Root");
        }
      }
    }
    return () => {
      console.log("exit from splash");
    };
  }, [books, userProducts, blogs]);

  if (isFocused && out) {
    setOut(false);
    BackHandler.exitApp();
  }

  React.useEffect(() => {
    return () => {
      console.log("exit from splash");
    };
  }, []);

  if (isFocused && !out) {
    if (isLogin !== null) {
      if (isLogin === false) {
        setOut(true);
        navigation.navigate("Login");
      } else {
        if (blogs.length === 0) {
          getBlogs();
        } else if (books.length === 0) {
          getBooks({ vod: true });
        } else if (userProducts.length === 0) {
          getUserProducts();
        } else {
          setOut(true);
          navigation.navigate("Root");
        }
      }
    }
  }

  return (
    <View
      style={{
        justifyContent: "center",
        alignItems: "center",
        flex: 1,
        display: "flex",
      }}
    >
      <View style={{ height: (width * 0.7 * 2) / 3 }}>
        <Image
          source={Logo}
          resizeMode="contain"
          style={{
            width: width * 0.7,
            flex: 1,
          }}
        />
      </View>
      <ActivityIndicator size={"large"} style={{ marginTop: 20 }} />
    </View>
  );
}

const mapStateToProps = (state) => ({
  isLogin: state.user.status,
  blogs: state.blog.list,
  books: state.book.list,
  userProducts: state.userProduct.list,
  theme: state.publicApi.theme,
});

const mapDispatchToProps = {
  getBlogs: blog.list,
  getBooks: book.list,
  getUserProducts: userProduct.list,
  setIsDark: publicApi.setIsDark,
};

export default connect(mapStateToProps, mapDispatchToProps)(Splash);
