import React from "react";
import { View, Text, Dimensions, Pressable, Appearance } from "react-native";
import { connect } from "react-redux";
import { publicApi } from "../../../../redux/actions";
import { useNavigation } from "@react-navigation/native";

//style
import tw from "tailwind-rn";
import fontSize from "../../../../constants/fontSize";
import Colors from "../../../../constants/Colors";

const { width } = Dimensions.get("window");

const duration = (value) => {
  const minute = value % 60;
  const hour = Math.round(value / 60);
  return (
    (hour > 0
      ? (hour.toString().length === 1 ? "0" + hour.toString() : hour) + ""
      : "") +
    ":" +
    (minute.toString().length === 1 ? "0" + minute.toString() : minute)
  );
};

const Season = ({
  season,
  activeUnit,
  name,
  setVideoActive,
  mobile,
  theme,
}) => {
  const navigation = useNavigation();

  const Unit = ({ unit }) => {
    const selectVideo = () => {
      setVideoActive(unit);
      navigation.navigate("VideoDisplay", {
        season: season,
        unit: unit,
        name: name,
      });
    };
    return (
      <View
        style={[
          tw(
            `w-full flex  rounded-md overflow-hidden ${
              mobile ? "mb-5" : "mb-5"
            }`
          ),
          {
            borderWidth: 1,
            borderColor: Colors.theme1.greenD9,
            backgroundColor:
              activeUnit === unit
                ? Colors.theme1.greenCF + (theme === "light" ? "" : "aa")
                : "transparent",
          },
        ]}
      >
        <View
          style={[
            tw(
              "w-full flex flex-row-reverse justify-between items-center py-2 px-3"
            ),
            {
              borderBottomWidth: 1,
              borderColor: Colors.theme1.greenD9,
            },
          ]}
        >
          <Text
            style={[
              {
                fontFamily: "bold",
                fontSize: mobile ? fontSize.base : fontSize.xl,
                color:
                  activeUnit === unit
                    ? "white"
                    : theme === "light"
                    ? Colors.theme1.green79
                    : Colors.theme1.white,
              },
            ]}
          >
            {unit.name}
          </Text>
          <Text
            style={[
              {
                fontFamily: "bold",
                fontSize: mobile ? fontSize.base : fontSize.xl,
                color:
                  activeUnit === unit
                    ? "white"
                    : theme === "light"
                    ? Colors.theme1.green79
                    : Colors.theme1.white,
                borderRightWidth: 1,
                borderColor:
                  activeUnit === unit
                    ? "white"
                    : theme === "light"
                    ? Colors.theme1.green79
                    : Colors.theme1.white,
                paddingRight: 8,
              },
            ]}
          >
            {duration(unit.duration)}
          </Text>
        </View>
        <View style={[tw("w-full flex flex-row-reverse")]}>
          <Pressable
            style={[tw("flex flex-1 flex-row items-center py-2 px-2")]}
            onPress={() => selectVideo()}
          >
            <Text
              style={{
                width: "100%",
                textAlign: "center",
                fontFamily: "demi",
                fontSize: mobile ? fontSize.base : fontSize.xl,
                color:
                  activeUnit === unit
                    ? "white"
                    : theme === "light"
                    ? Colors.theme1.green79
                    : Colors.theme1.white,
              }}
            >
              نمایش
            </Text>
          </Pressable>
        </View>
      </View>
    );
  };
  return (
    <View style={tw("w-full flex ")}>
      {season.map((unit, index) => (
        <Unit unit={unit} key={index} />
      ))}
    </View>
  );
};

const mapStateToProps = (state) => ({
  selectedVideo: state.publicApi.selectedVideo,
  realSeasons: state.publicApi.bookInfo?.categories,
  vods: state.publicApi.bookSection?.vods,
  userid: state.user.status?.id,
  mobile: state.publicApi.mobile,
  theme: state.publicApi.theme,
});

const mapDispatchToProps = {
  setVideoActive: publicApi.setVideoActive,
};

export default connect(mapStateToProps, mapDispatchToProps)(Season);
