import React from "react";
import {
  View,
  FlatList,
  Pressable,
  Image,
  Dimensions,
  Text,
  Appearance,
} from "react-native";
import { useNavigation } from "@react-navigation/native";
import { connect } from "react-redux";
import separate from "../../../utils/separate";
//style
import tw from "tailwind-rn";
import fontSize from "../../../constants/fontSize";
import Colors from "../../../constants/Colors";

//components
import Header from "../../Home/components/Header";

const { width } = Dimensions.get("window");

function MostViewedVideo({ videos, grades, mobile, theme }) {
  const navigation = useNavigation();

  const Video = React.useCallback(
    ({ video }) => {
      return (
        <Pressable
          style={[
            {
              width: mobile ? width / 1.5 : width / 2.2,
            },
            tw("flex  items-end rounded-md ml-6"),
          ]}
          onPress={() => navigation.navigate("Video", { id: video.id })}
        >
          <View
            style={[
              tw(
                "w-full flex flex-row flex-1 justify-between items-center relative overflow-hidden"
              ),
              { height: ((mobile ? width / 1.5 : width / 2.2) * 9) / 16 },
            ]}
          >
            <Image
              source={{ uri: `https://dnvn.ir/api/v1/file/${video.fileIds}` }}
              style={tw("w-full h-full absolute left-0 top-0 rounded-sm")}
            />
            <Image
              source={{ uri: `https://dnvn.ir/api/v1/file/${video.fileIds}` }}
              resizeMode="contain"
              style={[
                tw(
                  `rounded-sm h-full absolute left-2 ${mobile ? "" : "top-1/5"}`
                ),
                {
                  width: mobile ? 70 : 105,
                  height: mobile ? 110 : 150,
                  borderWidth: 2,
                  borderColor: "white",
                },
              ]}
            />
          </View>
          <Text
            style={{
              fontSize: mobile ? fontSize.base : fontSize.xl,
              marginTop: 5,
              paddingRight: 4,
              color:
                theme === "light" ? Colors.theme1.gray20 : Colors.theme1.white,
              fontFamily: "regular",
            }}
          >
            {"دوره ویدئویی" + " " + video?.name}
          </Text>

          <View
            style={tw(
              "w-full flex flex-row justify-between items-center px-1 mt-0"
            )}
          >
            <View style={tw("flex flex-row items-center")}>
              <Text
                style={[
                  {
                    color:
                      theme === "light"
                        ? Colors.theme1.gray20
                        : Colors.theme1.white,
                    fontFamily: "bold",
                    fontSize: mobile ? fontSize.sm : fontSize.tiny,
                    marginRight: 3,
                  },
                ]}
              >
                تومان
              </Text>
              <Text
                style={[
                  {
                    color:
                      theme === "light"
                        ? Colors.theme1.gray20
                        : Colors.theme1.white,
                    fontFamily: "bold",
                    fontSize: mobile ? fontSize.xl : fontSize.xl3,
                  },
                ]}
              >
                {separate(video?.product[2]?.price)}
              </Text>
            </View>

            <Text
              style={{
                color:
                  theme === "light"
                    ? Colors.theme1.gray20
                    : Colors.theme1.white,
                fontFamily: "light",
                fontSize: mobile ? fontSize.tiny : fontSize.lg,
                marginTop: 0,
              }}
            >
              {"پایه" + " " + grades[video?.gradeId]}
            </Text>
          </View>
        </Pressable>
      );
    },
    [videos, theme, mobile]
  );

  return (
    <View style={tw("w-full flex  w-full mt-3")}>
      <Header
        title="پربازدیدترین"
        route={"Products"}
        state={{ productType: "دوره ویدئویی" }}
      />
      <FlatList
        showsHorizontalScrollIndicator={false}
        horizontal={true}
        inverted={true}
        style={tw("pb-1.5 mt-3 flex flex-row w-full")}
        data={videos.slice(0, 7)}
        renderItem={({ item }) => <Video video={item} />}
        keyExtractor={(item) => item.id}
      />
    </View>
  );
}

const mapStateToProps = (state) => ({
  mobile: state.publicApi.mobile,
  theme: state.publicApi.theme,
});

export default connect(mapStateToProps)(MostViewedVideo);
