import React from "react";
import {
  View,
  Pressable,
  Image,
  Dimensions,
  Text,
  Platform,
} from "react-native";
import { useNavigation } from "@react-navigation/native";
import { connect } from "react-redux";

//style
import tw from "tailwind-rn";
import fontSize from "../../../constants/fontSize";
import Colors from "../../../constants/Colors";

//components
import Header from "../../Home/components/Header";

const { width } = Dimensions.get("window");
const ios = Platform.OS === "ios";


const NewestVideo = ({ videos, grades, mobile, theme }) => {
  const navigation = useNavigation();
  
  const Video = ({ video }) => {
    return (
      <Pressable
        style={[
          {
            width: mobile ? width / 2.3 : width / 3.3,
          },
          tw("flex  items-end mb-4"),
        ]}
        onPress={() => navigation.navigate("Video", { id: video.id })}
      >
        <Image
          source={{ uri: `https://dnvn.ir/api/v1/file/${video.fileIds}` }}
          style={[
            tw("rounded-sm"),
            {
              width: "100%",
              height: ((mobile ? width / 2.3 : width / 3.3) * 3) / 4,
            },
          ]}
        />
        <Text
          style={{
            fontSize: mobile ? fontSize.base : fontSize.xl,
            marginTop: 5,
            color: theme === 'light' ? Colors.theme1.gray20 : Colors.theme1.white,
            fontFamily: "bold",
          }}
        >
          {video.name}
        </Text>
        <Text
          style={{
            color: theme === 'light' ? Colors.theme1.gray20 : Colors.theme1.white,
            fontFamily: "light",
            fontSize: mobile ? fontSize.tiny : fontSize.lg,
            marginTop: 5,
          }}
        >
          {"پایه" + " " + grades[video.gradeId]}
        </Text>
      </Pressable>
    );
  };
  return (
    <View style={tw("w-full flex  w-full")}>
      <Header title="جدیدترین‌ دوره‌ها" route="" />
      <View
        style={tw(
          `w-full flex flex-wrap justify-between mt-3 ${
            ios ? "flex-row-reverse" : "flex-row"
          }`
        )}
      >
        {videos.map((video, index) => (
          <Video video={video} key={index} />
        ))}
      </View>
    </View>
  );
};

const mapStateToProps = (state) => ({
  mobile: state.publicApi.mobile,
  theme: state.publicApi.theme
});

export default connect(mapStateToProps)(NewestVideo);
